@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Algebraic_kernel_d/include/CGAL/Algebraic_kernel_d/Descartes.h $
-// $Id: Descartes.h 26355e2 2020-06-25T12:31:21+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Algebraic_kernel_d/include/CGAL/Algebraic_kernel_d/Descartes.h $
+// $Id: include/CGAL/Algebraic_kernel_d/Descartes.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -68,9 +68,9 @@ private:
 
     Polynomial poly_;
     int number_of_real_roots_;
-    IT* numerator;
-    IT* denominator_exponent;
-    bool* is_exact;
+    std::vector<IT> numerator;
+    std::vector<IT> denominator_exponent;
+    std::vector<bool> is_exact;
     IT LEFT,SCALE,DENOM;
     bool is_strong_;
     int k;
@@ -91,9 +91,9 @@ public:
           k(kk),
           interval_given(false) {
 
-        numerator = new IT[CGAL::degree(P)];
-        denominator_exponent = new IT[CGAL::degree(P)];
-        is_exact = new bool[CGAL::degree(P)];
+        numerator.resize(CGAL::degree(P));
+        denominator_exponent.resize(CGAL::degree(P));
+        is_exact.resize(CGAL::degree(P));
         number_of_real_roots_ = 0;
         if(CGAL::degree(P) == 0)
             {
@@ -116,9 +116,9 @@ public:
           k(kk),
           interval_given(true) {
 
-        numerator = new IT[CGAL::degree(P)];
-        denominator_exponent = new IT[CGAL::degree(P)];
-        is_exact = new bool[CGAL::degree(P)];
+        numerator.resize(CGAL::degree(P));
+        denominator_exponent.resize(CGAL::degree(P));
+        is_exact.resize(CGAL::degree(P));
         number_of_real_roots_ = 0;
         if(CGAL::degree(P) == 0)
             {
@@ -153,9 +153,9 @@ public:
           k(D.k),
           interval_given(D.interval_given) {
 
-        numerator = new IT[CGAL::degree(poly_)];
-        denominator_exponent = new IT[CGAL::degree(poly_)];
-        is_exact = new bool[CGAL::degree(poly_)];
+        numerator.resize(CGAL::degree(poly_));
+        denominator_exponent.resize(CGAL::degree(poly_));
+        is_exact.resize(CGAL::degree(poly_));
         for(int i=0; i<number_of_real_roots(); i++)
             {
                 numerator[i] = D.numerator[i];
@@ -166,9 +166,6 @@ public:
 
     // destructor
     ~Descartes() {
-        delete[] numerator;
-        delete[] denominator_exponent;
-        delete[] is_exact;
     }
 
 public: // functions
@@ -328,7 +325,7 @@ private:
             return false;
         return (P[0] != Coeff__(0) && P.evaluate(Coeff__(1)) != Coeff__(0));
     }
-    //! Descartes algoritm to determine isolating intervals for the roots
+    //! Descartes algorithm to determine isolating intervals for the roots
     //! lying in the interval (0,1).
     // The parameters $(i,D)$ describe the interval $(i/2^D, (i+1)/2^D)$.
     // Here $0\leq i < 2^D$.
@@ -389,7 +386,7 @@ private:
     }
 
 
-    //! Strong Descartes algoritm to determine isolating intervals for the
+    //! Strong Descartes algorithm to determine isolating intervals for the
     //! roots lying in the interval (0,1), where the first
     //! derivative have no sign change. \pre $P$ has only one root in the
     //! interval given by $(i,D)$.
