@@ -5,8 +5,8 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Alpha_shapes_2/include/CGAL/Alpha_shape_2.h $
-// $Id: Alpha_shape_2.h 1b189f40fd1 2025-03-03T16:27:24+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Alpha_shapes_2/include/CGAL/Alpha_shape_2.h $
+// $Id: include/CGAL/Alpha_shape_2.h 50219fc33bc $
 // Author(s)     : Tran Kai Frank DA
 //                 Andreas Fabri <Andreas.Fabri@geometryfactory.com>
 
@@ -61,7 +61,7 @@ public:
   // because the periodic triangulations' point() function returns a temporary
   // value while the lazy predicate evaluations that are used when the Exact tag
   // is set to true rely on a permanent and safe access to the points.
-  CGAL_static_assertion(
+  static_assert(
    (std::is_same<ExactAlphaComparisonTag, Tag_false>::value) ||
    (std::is_same<typename Dt::Periodic_tag, Tag_false>::value));
 
@@ -76,8 +76,8 @@ public:
   typedef Type_of_alpha               FT;
 
   // check that simplices are correctly instantiated
-  CGAL_static_assertion( (std::is_same<NT, typename Dt::Face::NT>::value) );
-  CGAL_static_assertion( (std::is_same<NT, typename Dt::Vertex::NT>::value) );
+  static_assert(std::is_same<NT, typename Dt::Face::NT>::value);
+  static_assert(std::is_same<NT, typename Dt::Vertex::NT>::value);
 
   typedef typename Dt::Point Point;
 
@@ -1442,7 +1442,7 @@ Alpha_shape_2<Dt,EACT>::find_alpha_solid() const
   // takes O(#alpha_shape) time
   Type_of_alpha alpha_solid = 0;
 
-  if (dimension()!=2) return alpha_solid;
+  if (number_of_vertices()<3) return alpha_solid;
 
   Finite_vertices_iterator vertex_it;
   // only finite vertices
