@@ -3,13 +3,14 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Arrangement_on_surface_2/include/CGAL/Arr_dcel_base.h $
-// $Id: Arr_dcel_base.h 4ea5251b9be 2022-06-10T16:44:17+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Arrangement_on_surface_2/include/CGAL/Arr_dcel_base.h $
+// $Id: include/CGAL/Arr_dcel_base.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
-// Author(s)     : Ron Wein <wein@post.tau.ac.il>
-//                 (based on old version by: Iddo Hanniel and Oren Nechushtan)
+// Author(s): Ron Wein          <wein@post.tau.ac.il>
+//            Efi Fogel         <efif@post.tau.ac.il>
+//            (based on old version by: Iddo Hanniel and Oren Nechushtan)
 
 #ifndef CGAL_ARR_DCEL_BASE_H
 #define CGAL_ARR_DCEL_BASE_H
@@ -23,11 +24,12 @@
  * peripheral records.
  */
 
-#include <CGAL/basic.h>
-#include <CGAL/Arr_enums.h>
 #include <list>
 #include <map>
-#include <CGAL/N_step_adaptor_derived.h>
+
+#include <CGAL/basic.h>
+#include <CGAL/Arr_enums.h>
+#include <CGAL/iterator.h>
 #include <CGAL/In_place_list.h>
 #include <CGAL/function_objects.h>
 #include <CGAL/Iterator_project.h>
@@ -38,7 +40,7 @@ namespace CGAL {
 
 inline void* _clean_pointer(const void* p)
 {
-  CGAL_static_assertion(sizeof(void*) == sizeof(size_t));
+  static_assert(sizeof(void*) == sizeof(size_t));
   const size_t  mask = ~1;
   const size_t  val = (reinterpret_cast<size_t>(p) & mask);
 
