@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Arrangement_on_surface_2/include/CGAL/Arr_non_caching_segment_traits_2.h $
-// $Id: Arr_non_caching_segment_traits_2.h 014c06fd19a 2022-11-14T15:32:47+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Arrangement_on_surface_2/include/CGAL/Arr_non_caching_segment_traits_2.h $
+// $Id: include/CGAL/Arr_non_caching_segment_traits_2.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Efi Fogel    <efif@post.tau.ac.il>
@@ -27,7 +27,7 @@
  * functors required by the concept it models.
  */
 
-#include <boost/variant.hpp>
+#include <variant>
 
 #include <CGAL/Exact_predicates_exact_constructions_kernel.h>
 #include <CGAL/tags.h>
@@ -131,7 +131,7 @@ public:
     OutputIterator operator()(const Curve_2& cv, OutputIterator oi) const
     {
       // Wrap the segment with a variant.
-      typedef boost::variant<Point_2, X_monotone_curve_2>
+      typedef std::variant<Point_2, X_monotone_curve_2>
         Make_x_monotone_result;
       *oi++ = Make_x_monotone_result(cv);
       return oi;
@@ -224,8 +224,6 @@ public:
                               OutputIterator oi) const
     {
       typedef std::pair<Point_2, Multiplicity>          Intersection_point;
-      typedef boost::variant<Intersection_point, X_monotone_curve_2>
-                                                        Intersection_result;
 
       const Kernel& kernel = m_traits;
       auto res = kernel.intersect_2_object()(cv1, cv2);
@@ -234,19 +232,19 @@ public:
       if (! res) return oi;
 
       // Check if the intersection is a point:
-      const Point_2* p_p = boost::get<Point_2>(&*res);
+      const Point_2* p_p = std::get_if<Point_2>(&*res);
       if (p_p != nullptr) {
         // Create a pair representing the point with its multiplicity,
         // which is always 1 for line segments for all practical purposes.
         // If the two segments intersect at their endpoints, then the
         // multiplicity is undefined, but we deliberately ignore it for
         // efficiency reasons.
-        *oi++ = Intersection_result(Intersection_point(*p_p, 1));
+        *oi++ = Intersection_point(*p_p, 1);
         return oi;
       }
 
       // The intersection is a segment.
-      const X_monotone_curve_2* cv_p = boost::get<X_monotone_curve_2>(&*res);
+      const X_monotone_curve_2* cv_p = std::get_if<X_monotone_curve_2>(&*res);
       CGAL_assertion(cv_p != nullptr);
 
       Comparison_result cmp1 = m_traits.compare_endpoints_xy_2_object()(cv1);
@@ -257,11 +255,11 @@ public:
         // in the overlap segment
         if (m_traits.compare_endpoints_xy_2_object()(*cv_p) != cmp1) {
           auto ctr_opposite = kernel.construct_opposite_segment_2_object();
-          *oi++ = Intersection_result(ctr_opposite(*cv_p));
+          *oi++ = ctr_opposite(*cv_p);
           return oi;
         }
       }
-      *oi++ = Intersection_result(*cv_p);
+      *oi++ = *cv_p;
       return oi;
     }
   };
