@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Barycentric_coordinates_2/include/CGAL/Barycentric_coordinates_2/internal/utils_2.h $
-// $Id: utils_2.h 62a31babbd1 2022-11-14T17:44:33+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Barycentric_coordinates_2/include/CGAL/Barycentric_coordinates_2/internal/utils_2.h $
+// $Id: include/CGAL/Barycentric_coordinates_2/internal/utils_2.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -31,7 +31,7 @@
 
 // Boost headers.
 #include <boost/mpl/has_xxx.hpp>
-#include <boost/optional/optional.hpp>
+#include <optional>
 
 // Internal includes.
 #include <CGAL/Weights/internal/polygon_utils_2.h>
@@ -222,7 +222,7 @@ namespace internal {
   typename VertexRange,
   typename GeomTraits,
   typename PointMap>
-  boost::optional< std::pair<Query_point_location, std::size_t> >
+  std::optional< std::pair<Query_point_location, std::size_t> >
   get_edge_index_approximate(
     const VertexRange& polygon,
     const typename GeomTraits::Point_2& query,
@@ -264,7 +264,7 @@ namespace internal {
         return std::make_pair(Query_point_location::ON_EDGE, i);
       }
     }
-    return boost::none;
+    return std::nullopt;
   }
 
   // Why this one does not work for harmonic coordinates? - Due to the imprecisions in the Mesh_2 class.
@@ -273,7 +273,7 @@ namespace internal {
   typename VertexRange,
   typename GeomTraits,
   typename PointMap>
-  boost::optional< std::pair<Query_point_location, std::size_t> >
+  std::optional< std::pair<Query_point_location, std::size_t> >
   get_edge_index_exact(
     const VertexRange& polygon,
     const typename GeomTraits::Point_2& query,
@@ -303,7 +303,7 @@ namespace internal {
         return std::make_pair(Query_point_location::ON_EDGE, i);
       }
     }
-    return boost::none;
+    return std::nullopt;
   }
 
   // Check whether a query point belongs to the last polygon edge.
@@ -409,7 +409,7 @@ namespace internal {
   typename VertexRange,
   typename GeomTraits,
   typename PointMap>
-  boost::optional< std::pair<Query_point_location, std::size_t> >
+  std::optional< std::pair<Query_point_location, std::size_t> >
   locate_wrt_polygon_2(
     const VertexRange& polygon,
     const typename GeomTraits::Point_2& query,
@@ -430,7 +430,7 @@ namespace internal {
       default:
         return std::make_pair(Query_point_location::UNSPECIFIED, std::size_t(-1));
     }
-    return boost::none;
+    return std::nullopt;
   }
 
 } // namespace internal
