@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Cartesian_kernel/include/CGAL/Cartesian/Point_3.h $
-// $Id: Point_3.h cca0a1942fa 2022-04-12T16:14:39+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Cartesian_kernel/include/CGAL/Cartesian/Point_3.h $
+// $Id: include/CGAL/Cartesian/Point_3.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -42,11 +42,17 @@ public:
   PointC3(const Origin &)
     : base(NULL_VECTOR) {}
 
-  PointC3(const FT &x, const FT &y, const FT &z)
-    : base(x, y, z) {}
 
-  PointC3(const FT &x, const FT &y, const FT &z, const FT &w)
-    : base(x, y, z, w) {}
+  template <class T1, class T2, class T3>
+  PointC3(T1 &&x, T2 &&y, T3 &&z)
+    : base(std::forward<T1>(x), std::forward<T2>(y), std::forward<T3>(z))
+  {}
+
+  template <class T1, class T2, class T3, class T4>
+  PointC3(T1 &&x, T2 &&y, T3 &&z, T4 &&w)
+    : base(std::forward<T1>(x), std::forward<T2>(y),
+           std::forward<T3>(z), std::forward<T4>(w))
+  {}
 
   friend void swap(Self& a, Self& b)
 #if !defined(__INTEL_COMPILER) && defined(__cpp_lib_is_swappable)
