@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Cartesian_kernel/include/CGAL/Cartesian/Segment_2.h $
-// $Id: Segment_2.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Cartesian_kernel/include/CGAL/Cartesian/Segment_2.h $
+// $Id: include/CGAL/Cartesian/Segment_2.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -39,7 +39,7 @@ public:
   {}
 
   SegmentC2(const Point_2 &sp, const Point_2 &ep)
-    : base(CGAL::make_array(sp, ep))
+    : base{sp, ep}
   {}
 
   const Point_2 &
