@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Combinatorial_map/include/CGAL/Combinatorial_map/internal/Combinatorial_map_utility.h $
-// $Id: Combinatorial_map_utility.h 7a62583efa1 2022-11-14T19:14:33+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Combinatorial_map/include/CGAL/Combinatorial_map/internal/Combinatorial_map_utility.h $
+// $Id: include/CGAL/Combinatorial_map/internal/Combinatorial_map_utility.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -342,23 +342,24 @@ namespace CGAL
     //is called for case k only if the k'th type in the tuple
     //is different from Void. Note that to the converse of Foreach_static
     //Functor are called from n =0 to k
-    template <class Functor,class T,int n=0>
+    template <class Functor,class T,int n=0, int startn=0>
     struct Foreach_static_restricted;
 
-    template <class Functor,class Head, class ... Items,int n>
+    template <class Functor,class Head, class ... Items,int n, int startn>
     struct Foreach_static_restricted<Functor,
-                                     std::tuple<Head,Items...>,n>
+                                     std::tuple<Head,Items...>,n, startn>
     {
       template <class  ... T>
       static void run(T& ... t){
-        Conditionnal_run<Functor,n,Head>::run(t...);
+        if(n>=startn)
+        { Conditionnal_run<Functor,n,Head>::run(t...); }
         Foreach_static_restricted
-          <Functor,std::tuple<Items...>,n+1>::run(t...);
+          <Functor,std::tuple<Items...>, n+1, startn>::run(t...);
       }
     };
 
-    template <class Functor,int n>
-    struct Foreach_static_restricted<Functor,std::tuple<>,n>{
+    template <class Functor,int n, int startn>
+    struct Foreach_static_restricted<Functor,std::tuple<>,n, startn>{
       template <class  ... T>
       static void run(T& ... ){}
     };
@@ -609,13 +610,13 @@ namespace CGAL
       struct Attribute_const_range<d, CGAL::Void>
       { typedef CGAL::Void type; };
 
-      // To iterate onto each enabled attributes
-      template <class Functor>
+      // To iterate onto each enabled attributes, starting from startn-attributes (0 by default)
+      template <class Functor, int startn=0>
       struct Foreach_enabled_attributes
       {
         template <class ...Ts>
         static void run(Ts& ... t)
-        { Foreach_static_restricted<Functor, Attributes>::run(t...); }
+        { Foreach_static_restricted<Functor, Attributes, 0, startn>::run(t...); }
       };
       // To iterate onto each enabled attributes, except j-attributes
       template <class Functor, unsigned int j>
