@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Surface_mesher/include/CGAL/Complex_2_in_triangulation_vertex_base_3.h $
-// $Id: Complex_2_in_triangulation_vertex_base_3.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Surface_mesher/include/CGAL/Complex_2_in_triangulation_vertex_base_3.h $
+// $Id: include/CGAL/Complex_2_in_triangulation_vertex_base_3.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,7 +18,10 @@
 
 #include <CGAL/license/Surface_mesher.h>
 
-
+#define CGAL_DEPRECATED_HEADER "<CGAL/Complex_2_in_triangulation_vertex_base_3.h>"
+#define CGAL_DEPRECATED_MESSAGE_DETAILS \
+  "The 3D Mesh Generation package (see https://doc.cgal.org/latest/Mesh_3/) should be used instead."
+#include <CGAL/Installation/internal/deprecation_warning.h>
 
 #include <CGAL/Triangulation_vertex_base_3.h>
 
