@@ -3,9 +3,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/Point_2.h $
-// $Id: Point_2.h ccdb5a0b54a 2023-02-15T14:36:44+02:00 Efi Fogel
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/Point_2.h $
+// $Id: include/CGAL/Curved_kernel_via_analysis_2/Point_2.h 50219fc33bc $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Eric Berberich <eric@mpi-inf.mpg.de>
@@ -14,6 +14,9 @@
 #ifndef CGAL_CURVED_KERNEL_VIA_ANALYSIS_2_POINT_2_H
 #define CGAL_CURVED_KERNEL_VIA_ANALYSIS_2_POINT_2_H
 
+#include <CGAL/license/Arrangement_on_surface_2.h>
+
+
 /*!\file include/CGAL/Curved_kernel_via_analysis_2/Point_2.h
  * \brief defines class \c Point_2 that represents a point on a curve that can
  * be analyzed.
@@ -21,7 +24,7 @@
 
 #include <CGAL/config.h>
 
-#include <boost/optional.hpp>
+#include <optional>
 #include <boost/optional/optional_io.hpp>
 
 #include <CGAL/Handle_with_policy.h>
@@ -106,22 +109,22 @@ public:
     //! curve point finite coordinates. They are valid only if boundary in y
     //! is not set (CGAL::NO_BOUNDARY), otherwise only x-coordinate is
     //! accessible, i.e., point is in interior
-    boost::optional< Coordinate_2 > _m_xy;
+    std::optional< Coordinate_2 > _m_xy;
 
     //! x-coordinate of a curve point
-    boost::optional< Coordinate_1 > _m_x;
+    std::optional< Coordinate_1 > _m_x;
 
     //! curve of point at boundary
-    boost::optional< Curve_analysis_2 > _m_curve;
+    std::optional< Curve_analysis_2 > _m_curve;
 
     //! arc of point at boundary
-    boost::optional< int > _m_arcno;
+    std::optional< int > _m_arcno;
 
     //! location of a point in parameter space
     mutable CGAL::Arr_parameter_space _m_location;
 
     //! store a double approximation of point
-    mutable boost::optional< std::pair< double, double > > _m_doubles;
+    mutable std::optional< std::pair< double, double > > _m_doubles;
 };
 
 /*!\brief
@@ -700,14 +703,13 @@ public:
         default:
           // ASCII
           os << "Point_2(";
-
-          os << this->ptr()->_m_xy;
+          os << ::CGAL::IO::oformat(this->ptr()->_m_xy);
           os << ",";
-          os << this->ptr()->_m_x;
+          os << ::CGAL::IO::oformat(this->ptr()->_m_x);
           os << ",";
-          os << this->ptr()->_m_curve;
+          os << ::CGAL::IO::oformat(this->ptr()->_m_curve);
           os << ",";
-          os << this->ptr()->_m_arcno;
+          os << ::CGAL::IO::oformat(this->ptr()->_m_arcno);
           os << ",";
           os << this->ptr()->_m_location;
 
@@ -737,13 +739,13 @@ public:
     swallow(is, '(');
 
     // read values
-    is >> rep._m_xy;
+    is >> IO::iformat(rep._m_xy);
     swallow(is, ',');
-    is >> rep._m_x;
+    is >> IO::iformat(rep._m_x);
     swallow(is, ',');
-    is >> rep._m_curve;
+    is >> IO::iformat(rep._m_curve);
     swallow(is, ',');
-    is >> rep._m_arcno;
+    is >> IO::iformat(rep._m_arcno);
     swallow(is, ',');
     is >> rep._m_location;
 
