@@ -3,9 +3,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/gfx/Subdivision_2.h $
-// $Id: Subdivision_2.h 014c06fd19a 2022-11-14T15:32:47+01:00 albert-github
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/gfx/Subdivision_2.h $
+// $Id: include/CGAL/Curved_kernel_via_analysis_2/gfx/Subdivision_2.h 50219fc33bc $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Pavel Emeliyanenko <asm@mpi-sb.mpg.de>
 //
@@ -17,7 +17,10 @@
  */
 
 #ifndef CGAL_CKVA_SUBDIVISION_2_H
-#define CGAL_CKVA_SUBDIVISION_2_H 1
+#define CGAL_CKVA_SUBDIVISION_2_H
+
+#include <CGAL/license/Arrangement_on_surface_2.h>
+
 
 #warning this file is considered obsolete
 
