@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Triangulation_2/include/CGAL/Delaunay_triangulation_2.h $
-// $Id: Delaunay_triangulation_2.h fbe559adc90 2023-02-14T08:32:33+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Triangulation_2/include/CGAL/Delaunay_triangulation_2.h $
+// $Id: include/CGAL/Delaunay_triangulation_2.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mariette Yvinec
@@ -301,7 +301,7 @@ public:
   std::ptrdiff_t
   insert(InputIterator first, InputIterator last,
          std::enable_if_t<
-           boost::is_convertible<
+           std::is_convertible<
              typename std::iterator_traits<InputIterator>::value_type,
              Point
            >::value
@@ -372,7 +372,7 @@ public:
   insert(InputIterator first,
          InputIterator last,
          std::enable_if_t<
-           boost::is_convertible<
+           std::is_convertible<
              typename std::iterator_traits<InputIterator>::value_type,
              std::pair<Point,typename internal::Info_check<typename Tds::Vertex>::type>
            >::value >* = nullptr)
@@ -385,10 +385,8 @@ public:
   insert(boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > first,
          boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > last,
          std::enable_if_t<
-           boost::mpl::and_<
-             boost::is_convertible< typename std::iterator_traits<InputIterator_1>::value_type, Point >,
-             boost::is_convertible< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Tds::Vertex>::type >
-           >::value
+             std::is_convertible_v< typename std::iterator_traits<InputIterator_1>::value_type, Point > &&
+             std::is_convertible_v< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Tds::Vertex>::type >
          >* = nullptr)
   {
     return insert_with_info< boost::tuple<Point,typename internal::Info_check<typename Tds::Vertex>::type> >(first,last);
