@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Kernel_23/include/CGAL/Exact_predicates_exact_constructions_kernel.h $
-// $Id: Exact_predicates_exact_constructions_kernel.h 98e471849bd 2021-08-26T11:33:39+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Kernel_23/include/CGAL/Exact_predicates_exact_constructions_kernel.h $
+// $Id: include/CGAL/Exact_predicates_exact_constructions_kernel.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -29,8 +29,15 @@
 
 namespace CGAL {
 
+constexpr bool epeck_use_static_filter =
+#ifdef CGAL_NO_STATIC_FILTERS
+    false;
+#else
+    true;
+#endif
+
 // Epeck_ft is either Gmpq, or leda_rational, or Quotient<MP_float>
-typedef internal::Exact_field_selector<double>::Type Epeck_ft;
+using Epeck_ft = internal::Exact_field_selector<double>::Type;
 
 // The following are redefined kernels instead of simple typedefs in order to shorten
 // template name length (for error messages, mangling...).
@@ -41,33 +48,36 @@ typedef internal::Exact_field_selector<double>::Type Epeck_ft;
 class Epeck
   : public Filtered_kernel_adaptor<
                Type_equality_wrapper< Simple_cartesian<Lazy_exact_nt<Epeck_ft> >::Base<Epeck>::Type, Epeck >,
-#ifdef CGAL_NO_STATIC_FILTERS
-               false >
-#else
-               true >
-#endif
+               epeck_use_static_filter >
 {}; // end class Epeck
 
 #else // no CGAL_DONT_USE_LAZY_KERNEL
 
+namespace internal {
+  template <typename FT>
+  using Epeck_sc = Simple_cartesian<FT>;
+  using Epeck_interval = Simple_cartesian<Interval_nt_advanced>;
+
+  template <typename FT>
+  using Epeck_converter = Cartesian_converter<Epeck_sc<FT>, Epeck_interval>;
+
+  template <typename FT, typename Kernel>
+  using Epeck_lazy_base = Lazy_kernel_base<Epeck_sc<FT>, Epeck_interval, Epeck_converter<FT>, Kernel>;
+
+  template <typename FT, typename Kernel>
+  using Epeck_lazy_base_with_type_equality = Type_equality_wrapper<Epeck_lazy_base<FT, Kernel>, Kernel>;
+} // namespace internal
+
 // Equivalent to Lazy_kernel<Simple_cartesian<Epeck_ft> >
-class Epeck
-  : public Type_equality_wrapper<
-             Lazy_kernel_base< Simple_cartesian<Epeck_ft>,
-                               Simple_cartesian<Interval_nt_advanced>,
-                               Cartesian_converter< Simple_cartesian<Epeck_ft>,
-                                                    Simple_cartesian<Interval_nt_advanced> >,
-                               Epeck>,
-             Epeck >
-{};
+class Epeck : public internal::Epeck_lazy_base_with_type_equality<Epeck_ft, Epeck> {};
 
 #endif // no CGAL_DONT_USE_LAZY_KERNEL
 
-typedef Epeck Exact_predicates_exact_constructions_kernel;
+using Exact_predicates_exact_constructions_kernel = Epeck;
 
 template <>
 struct Triangulation_structural_filtering_traits<Epeck> {
-  typedef Tag_true Use_structural_filtering_tag;
+  using Use_structural_filtering_tag = Tag_true;
 };
 
 } //namespace CGAL
