@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Surface_mesh_topology/include/CGAL/Face_graph_wrapper.h $
-// $Id: Face_graph_wrapper.h 440a8df 2022-02-03T08:41:04+00:00 Andreas Fabri
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Surface_mesh_topology/include/CGAL/Face_graph_wrapper.h $
+// $Id: include/CGAL/Face_graph_wrapper.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -40,7 +40,7 @@ class Face_graph_wrapper
 public:
   typedef HEG_                    HEG;
   typedef Face_graph_wrapper<HEG> Self;
-  typedef boost::uint32_t /*std::size_t*/ size_type;
+  typedef std::uint32_t /*std::size_t*/ size_type;
   typedef Self                    Refs;
 
   struct Dart_container
@@ -51,13 +51,13 @@ public:
     // typedef My_halfedge_iterator<HEG> const_iterator; // TODO ?
   };
 
-  typedef typename boost::graph_traits<HEG>::halfedge_descriptor Dart_handle;
-  typedef typename boost::graph_traits<HEG>::halfedge_descriptor Dart_const_handle;
+  typedef typename boost::graph_traits<HEG>::halfedge_descriptor Dart_descriptor;
+  typedef typename boost::graph_traits<HEG>::halfedge_descriptor Dart_const_descriptor;
 
-   typedef Dart_handle Null_handle_type;
-  // typedef CGAL::Void* Null_handle_type;
-   static const Null_handle_type null_handle; //=Dart_handle();
-   static const Null_handle_type null_dart_handle; //=Dart_handle();
+   typedef Dart_descriptor Null_descriptor_type;
+  // typedef CGAL::Void* Null_descriptor_type;
+   static const Null_descriptor_type null_descriptor; //=Dart_descriptor();
+   static const Null_descriptor_type null_dart_descriptor; //=Dart_descriptor();
 
   /// Number of marks
   static const size_type NB_MARKS = 32;
@@ -117,15 +117,15 @@ public:
   { return m_fg; }
 
   template<unsigned int i>
-  bool is_free(Dart_const_handle /* dh */) const
+  bool is_free(Dart_const_descriptor /* dh */) const
   { return false; } // Not possible to have a free dart with an HEG.
-  bool is_free(Dart_const_handle /*dh*/, unsigned int /*i*/) const
+  bool is_free(Dart_const_descriptor /*dh*/, unsigned int /*i*/) const
   { return false; } // Not possible to have a free dart with an HEG.
 
-  bool is_perforated(Dart_const_handle dh) const
+  bool is_perforated(Dart_const_descriptor dh) const
   { return is_border(dh, m_fg); }
 
-  Dart_const_handle get_beta(Dart_const_handle ADart, int B1) const
+  Dart_const_descriptor get_beta(Dart_const_descriptor ADart, int B1) const
   {
     CGAL_assertion(B1>=0 && B1<=static_cast<int>(dimension));
     if (B1==1) return internal::Get_beta<HEG, 1>::value(m_fg, ADart);
@@ -133,7 +133,7 @@ public:
     return internal::Get_beta<HEG, 0>::value(m_fg, ADart);
   }
   template<int B1>
-  Dart_const_handle get_beta(Dart_const_handle ADart) const
+  Dart_const_descriptor get_beta(Dart_const_descriptor ADart) const
   {
     CGAL_assertion(B1>=0 && B1<=static_cast<int>(dimension));
     return internal::Get_beta<HEG, B1>::value(m_fg, ADart);
@@ -142,52 +142,52 @@ public:
   bool is_empty() const
   { return number_of_darts()==0; }
 
-  /* ??  bool is_dart_used(Dart_const_handle dh) const
+  /* ??  bool is_dart_used(Dart_const_descriptor dh) const
       { return true; ?? } */
 
-  int highest_nonfree_dimension(Dart_const_handle /* dh */) const
+  int highest_nonfree_dimension(Dart_const_descriptor /* dh */) const
   { return 2; }
 
-  Dart_const_handle previous(Dart_const_handle ADart) const
+  Dart_const_descriptor previous(Dart_const_descriptor ADart) const
   { return get_beta<0>(ADart); }
-  Dart_const_handle next(Dart_const_handle ADart) const
+  Dart_const_descriptor next(Dart_const_descriptor ADart) const
   { return get_beta<1>(ADart); }
-  Dart_const_handle opposite(Dart_const_handle dh) const
+  Dart_const_descriptor opposite(Dart_const_descriptor dh) const
   { return get_beta<2>(dh); }
-  Dart_const_handle opposite2(Dart_const_handle dh) const
+  Dart_const_descriptor opposite2(Dart_const_descriptor dh) const
   { return get_beta<2>(dh); }
-  Dart_const_handle other_extremity(Dart_const_handle dh) const
+  Dart_const_descriptor other_extremity(Dart_const_descriptor dh) const
   { return get_beta<1>(dh); }
 
   template<unsigned int dim>
-  Dart_const_handle opposite(Dart_const_handle ADart) const
+  Dart_const_descriptor opposite(Dart_const_descriptor ADart) const
   { return this->template get_beta<dim>(ADart); }
-  Dart_const_handle other_orientation(Dart_const_handle ADart) const
+  Dart_const_descriptor other_orientation(Dart_const_descriptor ADart) const
   { return ADart; }
 
-  bool is_previous_exist(Dart_const_handle) const
+  bool is_previous_exist(Dart_const_descriptor) const
   { return true; }
-  bool is_next_exist(Dart_const_handle) const
+  bool is_next_exist(Dart_const_descriptor) const
   { return true; }
   template<unsigned int dim>
-  bool is_opposite_exist(Dart_const_handle /* ADart */) const
+  bool is_opposite_exist(Dart_const_descriptor /* ADart */) const
   { return true; }
 
   template<typename ...Betas>
-  Dart_handle beta(Dart_handle ADart, Betas... betas)
-  { return CGAL::internal::Beta_functor<Self, Dart_handle, Betas...>::
+  Dart_descriptor beta(Dart_descriptor ADart, Betas... betas)
+  { return CGAL::internal::Beta_functor<Self, Dart_descriptor, Betas...>::
       run(*this, ADart, betas...); }
   template<typename ...Betas>
-  Dart_const_handle beta(Dart_const_handle ADart, Betas... betas) const
-  { return CGAL::internal::Beta_functor<const Self, Dart_const_handle, Betas...>::
+  Dart_const_descriptor beta(Dart_const_descriptor ADart, Betas... betas) const
+  { return CGAL::internal::Beta_functor<const Self, Dart_const_descriptor, Betas...>::
       run(*this, ADart, betas...); }
   template<int... Betas>
-  Dart_handle beta(Dart_handle ADart)
-  { return CGAL::internal::Beta_functor_static<Self, Dart_handle, Betas...>::
+  Dart_descriptor beta(Dart_descriptor ADart)
+  { return CGAL::internal::Beta_functor_static<Self, Dart_descriptor, Betas...>::
       run(*this, ADart); }
   template<int... Betas>
-  Dart_const_handle beta(Dart_const_handle ADart) const
-  { return CGAL::internal::Beta_functor_static<const Self, Dart_const_handle, Betas...>::
+  Dart_const_descriptor beta(Dart_const_descriptor ADart) const
+  { return CGAL::internal::Beta_functor_static<const Self, Dart_const_descriptor, Betas...>::
       run(*this, ADart); }
 
   size_type number_of_darts() const
@@ -270,27 +270,27 @@ public:
   void mark_null_dart( size_type /*amark*/) const
   {}
 
-  bool get_dart_mark(Dart_const_handle ADart, size_type amark) const
+  bool get_dart_mark(Dart_const_descriptor ADart, size_type amark) const
   {
     CGAL_assertion(is_reserved(amark));
     return get(m_all_marks, ADart)[amark];
   }
-  void set_dart_mark(Dart_const_handle ADart, size_type amark, bool avalue) const
+  void set_dart_mark(Dart_const_descriptor ADart, size_type amark, bool avalue) const
   {
     CGAL_assertion(is_reserved(amark));
     const_cast<std::bitset<NB_MARKS>& >(get(m_all_marks, ADart)).set(amark, avalue);
   }
 
-  void flip_dart_mark(Dart_const_handle ADart, size_type amark) const
+  void flip_dart_mark(Dart_const_descriptor ADart, size_type amark) const
   { set_dart_mark(ADart, amark, !get_dart_mark(ADart, amark)); }
 
-  bool is_marked(Dart_const_handle adart, size_type amark) const
+  bool is_marked(Dart_const_descriptor adart, size_type amark) const
   {
     CGAL_assertion(is_reserved(amark));
     return get_dart_mark(adart, amark)!=mmask_marks[amark];
   }
 
-  void set_mark_to(Dart_const_handle adart, size_type amark,
+  void set_mark_to(Dart_const_descriptor adart, size_type amark,
                    bool astate) const
   {
     CGAL_assertion(is_reserved(amark));
@@ -304,7 +304,7 @@ public:
     }
   }
 
-  void mark(Dart_const_handle adart, size_type amark) const
+  void mark(Dart_const_descriptor adart, size_type amark) const
   {
     CGAL_assertion(is_reserved(amark));
 
@@ -314,9 +314,9 @@ public:
     flip_dart_mark(adart, amark);
   }
 
-  void unmark(Dart_const_handle adart, size_type amark) const
+  void unmark(Dart_const_descriptor adart, size_type amark) const
   {
-    CGAL_assertion( adart!=this->null_dart_handle );
+    CGAL_assertion( adart!=this->null_dart_descriptor );
     CGAL_assertion( is_reserved(amark) );
 
     if (!is_marked(adart, amark)) return;
@@ -389,12 +389,12 @@ public:
   {
     typedef CGAL::internal::FGW_cell_iterator<Self, i> iterator;
     typedef CGAL::internal::FGW_cell_iterator<Self, i> const_iterator;
-    Dart_of_cell_range(const Self &amap, Dart_handle adart) : mmap(amap),
+    Dart_of_cell_range(const Self &amap, Dart_descriptor adart) : mmap(amap),
                                                               m_initdart(adart),
                                                               msize(0)
     {}
     const_iterator begin() const { return const_iterator(mmap, m_initdart); }
-    const_iterator end() const   { return const_iterator(mmap, m_initdart, mmap.null_handle); }
+    const_iterator end() const   { return const_iterator(mmap, m_initdart, mmap.null_descriptor); }
     size_type size() const
     {
       if (msize==0)
@@ -409,7 +409,7 @@ public:
     { return mmap.is_empty(); }
   private:
     const Self & mmap;
-    Dart_handle m_initdart;
+    Dart_descriptor m_initdart;
     mutable typename Self::size_type msize;
   };
   //**************************************************************************
@@ -419,11 +419,11 @@ public:
   {}; */
   //--------------------------------------------------------------------------
   template<unsigned int i>
-  Dart_of_cell_range<i> darts_of_cell(Dart_handle adart)
+  Dart_of_cell_range<i> darts_of_cell(Dart_descriptor adart)
   { return Dart_of_cell_range<i>(*this,adart); }
   //--------------------------------------------------------------------------
   template<unsigned int i>
-  Dart_of_cell_range<i> darts_of_cell(Dart_const_handle adart) const
+  Dart_of_cell_range<i> darts_of_cell(Dart_const_descriptor adart) const
   { return Dart_of_cell_range<i>(*this,adart); } // Before it was Dart_of_cell_const_range<i>
   //**************************************************************************
   // Dart_range
@@ -433,9 +433,9 @@ public:
     Dart_range(const Self &amap) : mmap(amap), msize(0)
     {}
     iterator begin() { return iterator(mmap); }
-    iterator end()   { return iterator(mmap,mmap.null_handle); }
+    iterator end()   { return iterator(mmap,mmap.null_descriptor); }
     const_iterator begin() const { return const_iterator(mmap); }
-    const_iterator end() const   { return const_iterator(mmap,mmap.null_handle); }
+    const_iterator end() const   { return const_iterator(mmap,mmap.null_descriptor); }
     size_type size() const
     {
       if (msize==0)
@@ -457,7 +457,7 @@ public:
         run(mmap.get_fg(), *it);
     }
 
-    size_type index(Dart_const_handle it) const
+    size_type index(Dart_const_descriptor it) const
     {
       return internal::Index_from_halfedge_descriptor<HEG>::
         run(mmap.get_fg(), it);
@@ -474,7 +474,7 @@ public:
     Dart_const_range(const Self &amap) : mmap(amap), msize(0)
     {}
     const_iterator begin() const { return const_iterator(mmap); }
-    const_iterator end() const   { return const_iterator(mmap,mmap.null_handle); }
+    const_iterator end() const   { return const_iterator(mmap,mmap.null_descriptor); }
     size_type size() const
     {
       if (msize==0)
@@ -498,20 +498,20 @@ public:
   const Dart_range& darts() const
   { return mdarts; } // Before it was Dart_const_range(*this)
   //**************************************************************************
-  Dart_handle dart_handle(size_type i)
+  Dart_descriptor dart_descriptor(size_type i)
   {
     CGAL_assertion(darts().is_used(i));
     return internal::Halfedge_descriptor_from_index<HEG>::run(get_fg(), i);
   }
-  Dart_const_handle dart_handle(size_type i) const
+  Dart_const_descriptor dart_descriptor(size_type i) const
   {
     CGAL_assertion(darts().is_used(i));
     return internal::Halfedge_descriptor_from_index<HEG>::run(get_fg(), i);
   }
 
   template <unsigned int i>
-  bool belong_to_same_cell(Dart_const_handle adart1,
-                           Dart_const_handle adart2) const
+  bool belong_to_same_cell(Dart_const_descriptor adart1,
+                           Dart_const_descriptor adart2) const
   {
     for (typename Dart_of_cell_range<i>::iterator it=darts_of_cell<i>(adart1).begin(),
            itend=darts_of_cell<i>(adart1).end(); it!=itend; ++it)
@@ -520,7 +520,7 @@ public:
   }
 
   template <unsigned int i>
-  bool is_whole_cell_unmarked(Dart_const_handle adart, size_type amark) const
+  bool is_whole_cell_unmarked(Dart_const_descriptor adart, size_type amark) const
   {
     for (typename Dart_of_cell_range<i>::iterator it=darts_of_cell<i>(adart).begin(),
            itend=darts_of_cell<i>(adart).end(); it!=itend; ++it)
@@ -529,7 +529,7 @@ public:
   }
 
   template <unsigned int i>
-  bool is_whole_cell_marked(Dart_const_handle adart, size_type amark) const
+  bool is_whole_cell_marked(Dart_const_descriptor adart, size_type amark) const
   {
     for (typename Dart_of_cell_range<i>::iterator it=darts_of_cell<i>(adart).begin(),
            itend=darts_of_cell<i>(adart).end(); it!=itend; ++it)
@@ -538,7 +538,7 @@ public:
   }
 
   template <unsigned int i>
-  size_type mark_cell(Dart_const_handle adart, size_type amark) const
+  size_type mark_cell(Dart_const_descriptor adart, size_type amark) const
   {
     size_type res=0;
     for (typename Dart_of_cell_range<i>::iterator it=darts_of_cell<i>(adart).begin(),
@@ -547,7 +547,7 @@ public:
     return res;
 }
 
-  size_type mark_cell(Dart_const_handle adart, unsigned int i, size_type amark) const
+  size_type mark_cell(Dart_const_descriptor adart, unsigned int i, size_type amark) const
   {
     if (i==0) { return mark_cell<0>(adart, amark); }
     else if (i==1) { return mark_cell<1>(adart, amark); }
@@ -556,7 +556,7 @@ public:
   }
 
   template <unsigned int i>
-  size_type unmark_cell(Dart_const_handle adart, size_type amark) const
+  size_type unmark_cell(Dart_const_descriptor adart, size_type amark) const
   {
     size_type res=0;
     for (typename Dart_of_cell_range<i>::iterator it=darts_of_cell<i>(adart).begin(),
@@ -566,7 +566,7 @@ public:
   }
 
   template <unsigned int i>
-  size_type mark_oriented_cell(Dart_const_handle adart, size_type amark,
+  size_type mark_oriented_cell(Dart_const_descriptor adart, size_type amark,
                                size_type amark2=INVALID_MARK) const
   {
     size_type res=0;
@@ -580,7 +580,7 @@ public:
   }
 
   template <unsigned int i>
-  size_type unmark_oriented_cell(Dart_const_handle adart, size_type amark,
+  size_type unmark_oriented_cell(Dart_const_descriptor adart, size_type amark,
                                  size_type amark2=INVALID_MARK) const
   {
     size_type res=0;
@@ -740,21 +740,21 @@ protected:
   mutable MarkPMap m_all_marks;
 };
 
-  /// null_handle
+  /// null_descriptor
   // template <typename HEG>
-  // const typename Face_graph_wrapper<HEG>::Null_handle_type
-  // Face_graph_wrapper<HEG>::null_handle=nullptr;
+  // const typename Face_graph_wrapper<HEG>::Null_descriptor_type
+  // Face_graph_wrapper<HEG>::null_descriptor=nullptr;
   template <typename HEG>
-  const typename Face_graph_wrapper<HEG>::Null_handle_type
-  Face_graph_wrapper<HEG>::null_handle=typename Face_graph_wrapper<HEG>::Dart_handle();
+  const typename Face_graph_wrapper<HEG>::Null_descriptor_type
+  Face_graph_wrapper<HEG>::null_descriptor=typename Face_graph_wrapper<HEG>::Dart_descriptor();
 
-  /// null_dart_handle
+  /// null_dart_descriptor
   // template <typename HEG>
-  // const typename Face_graph_wrapper<HEG>::Null_handle_type
-  // Face_graph_wrapper<HEG>::null_dart_handle=nullptr;
+  // const typename Face_graph_wrapper<HEG>::Null_descriptor_type
+  // Face_graph_wrapper<HEG>::null_dart_descriptor=nullptr;
   template <typename HEG>
-  const typename Face_graph_wrapper<HEG>::Null_handle_type
-  Face_graph_wrapper<HEG>::null_dart_handle=typename Face_graph_wrapper<HEG>::Dart_handle();
+  const typename Face_graph_wrapper<HEG>::Null_descriptor_type
+  Face_graph_wrapper<HEG>::null_dart_descriptor=typename Face_graph_wrapper<HEG>::Dart_descriptor();
 
   template<class Base, class HEG>
   struct Get_map
@@ -893,8 +893,8 @@ protected:
     typedef typename Mesh::Point  Point;
     typedef typename Mesh::Vector Vector;
 
-    template<class Dart_handle>
-    static const Point& get_point(const Mesh& m, Dart_handle dh)
+    template<class Dart_descriptor>
+    static const Point& get_point(const Mesh& m, Dart_descriptor dh)
     { return m.point(dh); }
   };
 
@@ -906,8 +906,8 @@ protected:
     typedef typename Kernel::Point_3                Point;
     typedef typename Kernel::Vector_3               Vector;
 
-    template<class Dart_handle>
-    static const Point& get_point(const Mesh& m, Dart_handle dh)
+    template<class Dart_descriptor>
+    static const Point& get_point(const Mesh& m, Dart_descriptor dh)
     { return m.point(m.source(dh)); }
   };
 
@@ -924,8 +924,8 @@ protected:
     typedef typename Kernel::Point_3  Point;
     typedef typename Kernel::Vector_3 Vector;
 
-    template<class Dart_handle>
-    static const Point& get_point(const Mesh& /*m*/, Dart_handle dh)
+    template<class Dart_descriptor>
+    static const Point& get_point(const Mesh& /*m*/, Dart_descriptor dh)
     { return dh->opposite()->vertex()->point(); }
   };
 
