@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Spatial_sorting/include/CGAL/Hilbert_sort_median_3.h $
-// $Id: Hilbert_sort_median_3.h f60dfa81e2c 2022-04-04T10:00:16+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Spatial_sorting/include/CGAL/Hilbert_sort_median_3.h $
+// $Id: include/CGAL/Hilbert_sort_median_3.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Christophe Delage
@@ -18,8 +18,6 @@
 #include <cstddef>
 #include <CGAL/Hilbert_sort_base.h>
 
-#include <boost/type_traits/is_convertible.hpp>
-
 #ifdef CGAL_LINKED_WITH_TBB
 #include <tbb/parallel_invoke.h>
 #endif
@@ -180,8 +178,8 @@ public:
 #ifndef CGAL_LINKED_WITH_TBB
     CGAL_USE(begin);
     CGAL_USE(end);
-    CGAL_static_assertion_msg (!(boost::is_convertible<ConcurrencyTag, Parallel_tag>::value),
-                               "Parallel_tag is enabled but TBB is unavailable.");
+    static_assert (!std::is_convertible<ConcurrencyTag, Parallel_tag>::value,
+                   "Parallel_tag is enabled but TBB is unavailable.");
 #else
     const int y = (x + 1) % 3, z = (x + 2) % 3;
     if ((end - begin) <= _limit) return;
