@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Stream_support/include/CGAL/IO/Color.h $
-// $Id: Color.h 98ee8d7560e 2022-02-25T14:54:48+01:00 Charrière Maxime
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Stream_support/include/CGAL/IO/Color.h $
+// $Id: include/CGAL/IO/Color.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -19,12 +19,13 @@
 
 #include <CGAL/config.h>
 #include <CGAL/array.h>
+
+#include <boost/functional/hash.hpp>
+
 #include <algorithm>
 #include <cstdlib>
 #include <cmath>
 
-
-
 namespace CGAL {
 
 namespace IO {
@@ -150,13 +151,13 @@ public:
 
   /*!
     returns the \f$i^{th}\f$ component of the rgb color (the
-    \f$0^{th}\f$ is red, the \f$1^{st}\f$ is blue, etc.).
+    \f$0^{th}\f$ is red, the \f$1^{st}\f$ is green, the \f$2^{nd}\f$ is blue and the \f$3^{rd}\f$ is alpha).
   */
   unsigned char operator[] (std::size_t i) const { return m_data[i]; }
 
   /*!
-    returns a reference on the \f$i^{th}\f$ component of `c` (the
-    \f$0^{th}\f$ is red, the \f$1^{st}\f$ is blue, etc.).
+    returns a reference on the \f$i^{th}\f$ component of the rgb color (the
+    \f$0^{th}\f$ is red, the \f$1^{st}\f$ is green, the \f$2^{nd}\f$ is blue and the \f$3^{rd}\f$ is alpha).
   */
   unsigned char& operator[] (std::size_t i)  { return m_data[i]; }
 
@@ -287,7 +288,6 @@ public:
   }
 
   /// @}
-
 };
 
 
@@ -375,6 +375,22 @@ using IO::white;
 using IO::yellow;
 #endif
 
-} //namespace CGAL
+} // namespace CGAL
+
+namespace std {
+
+template <>
+struct hash<CGAL::IO::Color>
+{
+  std::size_t operator()(const CGAL::IO::Color& c) const
+  {
+    std::size_t result = boost::hash_value(c[0]);
+    for(std::size_t i=1; i<4; ++i)
+      boost::hash_combine(result, c[i]);
+    return result;
+  }
+};
+
+} // namespace std
 
 #endif  // CGAL_COLOR_H
