@@ -3,9 +3,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Triangulation/include/CGAL/IO/Triangulation_off_ostream.h $
-// $Id: Triangulation_off_ostream.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Triangulation/include/CGAL/IO/Triangulation_off_ostream.h $
+// $Id: include/CGAL/IO/Triangulation_off_ostream.h 50219fc33bc $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Clement Jamin
 
@@ -13,6 +13,9 @@
 #ifndef CGAL_TRIANGULATION_IO_H
 #define CGAL_TRIANGULATION_IO_H
 
+#include <CGAL/license/Triangulation.h>
+
+
 #include <CGAL/Epick_d.h>
 #include <CGAL/Triangulation.h>
 #include <sstream>
