@@ -3,9 +3,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Triangulation_2/include/CGAL/IO/Triangulation_off_ostream_2.h $
-// $Id: Triangulation_off_ostream_2.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Triangulation_2/include/CGAL/IO/Triangulation_off_ostream_2.h $
+// $Id: include/CGAL/IO/Triangulation_off_ostream_2.h 50219fc33bc $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Clement Jamin
 
@@ -13,6 +13,9 @@
 #ifndef CGAL_TRIANGULATION_OFF_OSTREAM_2_H
 #define CGAL_TRIANGULATION_OFF_OSTREAM_2_H
 
+#include <CGAL/license/Triangulation_2.h>
+
+
 #include <CGAL/Triangulation_2.h>
 #include <sstream>
 #include <iostream>
