@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Stream_support/include/CGAL/IO/helpers.h $
-// $Id: helpers.h 988d226d083 2023-04-11T14:19:09+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Stream_support/include/CGAL/IO/helpers.h $
+// $Id: include/CGAL/IO/helpers.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mael Rouxel-Labbé
@@ -77,23 +77,23 @@ struct is_Point_set_3 : has_Point_set<T> { };
 // Point_set_3 and strings also functions as ranges, but we want to match polygon soups here
 template <typename T>
 struct is_Range
-  : public boost::mpl::and_<
-             boost::has_range_const_iterator<T>, // should be a range
-             boost::mpl::not_<is_Point_set_3<T> >, // but not a Point_set_3
-             boost::mpl::not_<boost::is_convertible<T, std::string> > > // or a std::string / char [x]
+  : public std::bool_constant<
+             boost::has_range_const_iterator<T>::value && // should be a range
+             !is_Point_set_3<T>::value && // but not a Point_set_3
+             !std::is_convertible_v<T, std::string> > // or a std::string / char [x]
 { };
 
 template <class T>
-CGAL_CPP17_INLINE constexpr bool is_Range_v = is_Range<T>::value;
+inline constexpr bool is_Range_v = is_Range<T>::value;
 
 // For polygon meshes
 template <typename T>
 struct is_Point_set_or_Range_or_Iterator
-  : public boost::mpl::or_<is_Point_set_3<T>, is_Range<T>, is_iterator<T> >
+  : public std::bool_constant<is_Point_set_3<T>::value || is_Range<T>::value || is_iterator<T>::value >
 { };
 
 template <class T>
-CGAL_CPP17_INLINE constexpr bool is_Point_set_or_Range_or_Iterator_v = is_Point_set_or_Range_or_Iterator<T>::value;
+inline constexpr bool is_Point_set_or_Range_or_Iterator_v = is_Point_set_or_Range_or_Iterator<T>::value;
 
 } // end namespace internal
 } // end namespace IO
