@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Point_set_processing_3/include/CGAL/IO/read_las_points.h $
-// $Id: read_las_points.h 98f4633e5f2 2024-09-06T16:07:14+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Point_set_processing_3/include/CGAL/IO/read_las_points.h $
+// $Id: include/CGAL/IO/read_las_points.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Simon Giraudot
@@ -123,7 +123,7 @@ typedef Base<unsigned short, Id::I> I;
 /**
    \ingroup PkgPointSetProcessing3IOLas
 
-   Generates a %LAS property handler to read 3D points. Points are
+   generates a %LAS property handler to read 3D points. Points are
    constructed from the input the using 3 %LAS properties
    `LAS_property::X`, `LAS_property::Y` and `LAS_property::Z`.
 
@@ -578,11 +578,7 @@ bool read_las_points(std::istream& is, ///< input stream.
 
 /// \endcond
 
-/**
- \ingroup PkgPointSetProcessing3IODeprecated
 
- \deprecated This function is deprecated since \cgal 5.3, `CGAL::IO::read_LAS_with_properties()` should be used instead.
-*/
 template <typename OutputIteratorValueType,
           typename OutputIterator,
           typename ... PropertyHandler>
@@ -606,11 +602,6 @@ CGAL_DEPRECATED bool read_las_points_with_properties(std::istream& is,
 
 /// \endcond
 
-/**
- \ingroup PkgPointSetProcessing3IODeprecated
-
- \deprecated This function is deprecated since \cgal 5.3, `CGAL::IO::read_LAS()` should be used instead.
-*/
 template <typename OutputIteratorValueType,
           typename OutputIterator,
           typename CGAL_NP_TEMPLATE_PARAMETERS>
