@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Kernel_23/include/CGAL/Kernel_23/internal/Projection_traits_3.h $
-// $Id: Projection_traits_3.h 214e072959a 2022-09-22T12:02:53+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Kernel_23/include/CGAL/Kernel_23/internal/Projection_traits_3.h $
+// $Id: include/CGAL/Kernel_23/internal/Projection_traits_3.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mariette Yvinec, Sebastien Loriot, Mael Rouxel-Labbé
@@ -20,6 +20,7 @@
 
 #include <CGAL/Kernel/global_functions_2.h>
 #include <CGAL/Kernel_23/internal/Has_boolean_tags.h>
+#include <CGAL/Triangulation_structural_filtering_traits.h>
 
 namespace CGAL {
 
@@ -428,10 +429,10 @@ public:
 
 
 
-  boost::optional< boost::variant<Point_3,Segment_3> >
+  std::optional< std::variant<Point_3,Segment_3> >
   operator()(const Segment_3& s1, const Segment_3& s2) const
   {
-    typedef  boost::variant<Point_3, Segment_3> variant_type;
+    typedef  std::variant<Point_3, Segment_3> variant_type;
 
     Point_2 s1_source = project(s1.source());
     Point_2 s1_target = project(s1.target());
@@ -447,10 +448,10 @@ public:
 
     auto o = intersection(s1_2,s2_2);
     if(! o){
-      return boost::none;
+      return std::nullopt;
     }
 
-    if(const Segment_2* si = boost::get<Segment_2>(&*o)){
+    if(const Segment_2* si = std::get_if<Segment_2>(&*o)){
       FT src[3],tgt[3];
       //the third coordinate is the midpoint between the points on s1 and s2
       FT z1 = s1.source()[dim] + ( alpha(si->source(), s1_source, s1_target) * ( s1.target()[dim] - s1.source()[dim] ));
@@ -468,11 +469,11 @@ public:
       src[Projector<R,dim>::y_index] = si->source().y();
       tgt[Projector<R,dim>::x_index] = si->target().x();
       tgt[Projector<R,dim>::y_index] = si->target().y();
-      return boost::make_optional(variant_type(Segment_3( Point_3(src[0],src[1],src[2]),Point_3(tgt[0],tgt[1],tgt[2]) ) ) );
+      return std::make_optional(variant_type(Segment_3( Point_3(src[0],src[1],src[2]),Point_3(tgt[0],tgt[1],tgt[2]) ) ) );
     }
 
 
-    const Point_2* pi = boost::get<Point_2>(&*o);
+    const Point_2* pi = std::get_if<Point_2>(&*o);
     FT coords[3];
     //compute the third coordinate of the projected intersection point onto 3D segments
     FT z1 = s1.source()[dim] + ( alpha(*pi, s1_source, s1_target) * ( s1.target()[dim] - s1.source()[dim] ));
@@ -484,7 +485,7 @@ public:
 
     Point_3 res(coords[0],coords[1],coords[2]);
     CGAL_assertion(x(res)==pi->x() && y(res)==pi->y());
-    return boost::make_optional(variant_type(res));
+    return std::make_optional(variant_type(res));
   }
 };
 
@@ -970,6 +971,7 @@ public:
   typedef typename Rp::Construct_triangle_3                   Construct_triangle_2;
   typedef typename Rp::Construct_line_3                       Construct_line_2;
 
+  typedef typename Rp::Compare_xyz_3                          Compare_xy_2;
 
   struct Less_xy_2 {
     typedef typename R::Boolean result_type;
@@ -1064,6 +1066,10 @@ public:
   less_x_2_object() const
     { return Less_x_2();}
 
+  Compare_xy_2
+  compare_xy_2_object() const
+    { return Compare_xy_2();}
+
   Less_xy_2
   less_xy_2_object() const
     { return Less_xy_2();}
@@ -1210,6 +1216,14 @@ public:
 };
 
 
-} } //namespace CGAL::internal
+
+} // namespace internal
+
+template <class R, int dim>
+struct Triangulation_structural_filtering_traits<::CGAL::internal::Projection_traits_3<R,dim> > {
+  typedef typename Triangulation_structural_filtering_traits<R>::Use_structural_filtering_tag  Use_structural_filtering_tag;
+};
+
+ } //namespace CGAL
 
 #endif // CGAL_INTERNAL_PROJECTION_TRAITS_3_H
