@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Kernel_23/include/CGAL/Kernel_traits.h $
-// $Id: Kernel_traits.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Kernel_23/include/CGAL/Kernel_traits.h $
+// $Id: include/CGAL/Kernel_traits.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -19,7 +19,6 @@
 
 #include <CGAL/Kernel_traits_fwd.h>
 #include <boost/mpl/has_xxx.hpp>
-#include <boost/mpl/if.hpp>
 
 namespace CGAL {
 
