@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Mesh_3/include/CGAL/Mesh_3/Cell_criteria_visitor_with_balls.h $
-// $Id: Cell_criteria_visitor_with_balls.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Mesh_3/include/CGAL/Mesh_3/Cell_criteria_visitor_with_balls.h $
+// $Id: include/CGAL/Mesh_3/Cell_criteria_visitor_with_balls.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -45,8 +45,8 @@ public:
 
   typedef typename Tr::Bare_point      Bare_point;
   typedef typename Tr::Weighted_point  Weighted_point;
-  typedef typename Tr::Geom_traits     Gt;
-  typedef typename Gt::FT              FT;
+  typedef typename Tr::Geom_traits     GT;
+  typedef typename GT::FT              FT;
 
   int nb_weighted_points;
   std::vector<Weighted_point> points;
@@ -59,9 +59,9 @@ public:
   Cell_criteria_visitor_with_balls(const Tr& tr, const Cell_handle& ch)
     : Base(tr, ch)
   {
-    typename Gt::Compare_weighted_squared_radius_3 compare_sq_radius =
+    typename GT::Compare_weighted_squared_radius_3 compare_sq_radius =
       tr.geom_traits().compare_weighted_squared_radius_3_object();
-    typename Gt::Squared_radius_orthogonal_sphere sq_radius_ortho_sphere =
+    typename GT::Squared_radius_orthogonal_sphere sq_radius_ortho_sphere =
       tr.geom_traits().compute_squared_radius_smallest_orthogonal_sphere_3_object();
 
     const Weighted_point& p = tr.point(ch, 0);
