@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Mesh_3/include/CGAL/Mesh_3/Lloyd_move.h $
-// $Id: Lloyd_move.h cbfeb98 2022-10-05T15:39:04+02:00 Sebastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Mesh_3/include/CGAL/Mesh_3/Lloyd_move.h $
+// $Id: include/CGAL/Mesh_3/Lloyd_move.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -44,7 +44,7 @@ template <typename C3T3,
 class Lloyd_move
 {
   typedef typename C3T3::Triangulation                        Tr;
-  typedef typename Tr::Geom_traits                            Gt;
+  typedef typename Tr::Geom_traits                            GT;
 
   typedef typename Tr::Vertex_handle                          Vertex_handle;
   typedef typename Tr::Edge                                   Edge;
@@ -57,12 +57,12 @@ class Lloyd_move
   typedef typename std::vector<Facet>                         Facet_vector;
   typedef typename std::vector<Cell_handle>                   Cell_vector;
 
-  typedef typename Gt::FT                                     FT;
-  typedef typename Gt::Point_2                                Point_2;
-  typedef typename Gt::Vector_3                               Vector_3;
-  typedef typename Gt::Tetrahedron_3                          Tetrahedron_3;
-  typedef typename Gt::Plane_3                                Plane_3;
-  typedef typename Gt::Aff_transformation_3                   Aff_transformation_3;
+  typedef typename GT::FT                                     FT;
+  typedef typename GT::Point_2                                Point_2;
+  typedef typename GT::Vector_3                               Vector_3;
+  typedef typename GT::Tetrahedron_3                          Tetrahedron_3;
+  typedef typename GT::Plane_3                                Plane_3;
+  typedef typename GT::Aff_transformation_3                   Aff_transformation_3;
 
 public:
   typedef SizingField                                         Sizing_field;
@@ -261,7 +261,7 @@ private:
   {
     const Tr& tr = c3t3.triangulation();
 
-    typename Gt::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
+    typename GT::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
 
     Facet_vector incident_facets;
     incident_facets.reserve(64);
@@ -306,8 +306,8 @@ private:
                                  const C3T3& c3t3,
                                  const Sizing_field& sizing_field) const
   {
-    typename Gt::Construct_point_3 cp = c3t3.triangulation().geom_traits().construct_point_3_object();
-    typename Gt::Construct_vector_3 vector = c3t3.triangulation().geom_traits().construct_vector_3_object();
+    typename GT::Construct_point_3 cp = c3t3.triangulation().geom_traits().construct_point_3_object();
+    typename GT::Construct_vector_3 vector = c3t3.triangulation().geom_traits().construct_vector_3_object();
 
     const Weighted_point position = c3t3.triangulation().point(v);
     const Bare_point& p = cp(position);
@@ -329,8 +329,8 @@ private:
                                   const C3T3& c3t3,
                                   const Sizing_field& sizing_field) const
   {
-    typename Gt::Construct_point_3 cp = c3t3.triangulation().geom_traits().construct_point_3_object();
-    typename Gt::Construct_vector_3 vector = c3t3.triangulation().geom_traits().construct_vector_3_object();
+    typename GT::Construct_point_3 cp = c3t3.triangulation().geom_traits().construct_point_3_object();
+    typename GT::Construct_vector_3 vector = c3t3.triangulation().geom_traits().construct_vector_3_object();
 
     const Weighted_point& position = c3t3.triangulation().point(v);
     const Bare_point& p = cp(position);
@@ -409,10 +409,10 @@ private:
   {
     CGAL_precondition(std::distance(first,last) >= 3);
 
-    typename Gt::Compute_area_3 area = c3t3.triangulation().geom_traits().compute_area_3_object();
-    typename Gt::Construct_centroid_3 centroid = c3t3.triangulation().geom_traits().construct_centroid_3_object();
-    typename Gt::Construct_point_3 cp = c3t3.triangulation().geom_traits().construct_point_3_object();
-    typename Gt::Construct_vector_3 vector = c3t3.triangulation().geom_traits().construct_vector_3_object();
+    typename GT::Compute_area_3 area = c3t3.triangulation().geom_traits().compute_area_3_object();
+    typename GT::Construct_centroid_3 centroid = c3t3.triangulation().geom_traits().construct_centroid_3_object();
+    typename GT::Construct_point_3 cp = c3t3.triangulation().geom_traits().construct_point_3_object();
+    typename GT::Construct_vector_3 vector = c3t3.triangulation().geom_traits().construct_vector_3_object();
 
     // Vertex current position
     const Weighted_point& vertex_weighted_position = c3t3.triangulation().point(v);
@@ -460,8 +460,8 @@ private:
                                                const Bare_point& reference_point,
                                                const C3T3& c3t3) const
   {
-    typename Gt::Construct_base_vector_3 base = c3t3.triangulation().geom_traits().construct_base_vector_3_object();
-    typename Gt::Construct_orthogonal_vector_3 orthogonal_vector = c3t3.triangulation().geom_traits().construct_orthogonal_vector_3_object();
+    typename GT::Construct_base_vector_3 base = c3t3.triangulation().geom_traits().construct_base_vector_3_object();
+    typename GT::Construct_orthogonal_vector_3 orthogonal_vector = c3t3.triangulation().geom_traits().construct_orthogonal_vector_3_object();
 
     Vector_3 u = base(plane, 1);
     u = u / CGAL::sqrt(u*u);
@@ -542,12 +542,12 @@ private:
 
     const Tr& tr = c3t3.triangulation();
 
-    typename Gt::Construct_centroid_3 centroid = tr.geom_traits().construct_centroid_3_object();
-    typename Gt::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
-    typename Gt::Construct_tetrahedron_3 tetrahedron = tr.geom_traits().construct_tetrahedron_3_object();
-    typename Gt::Construct_translated_point_3 translate = tr.geom_traits().construct_translated_point_3_object();
-    typename Gt::Construct_vector_3 vector = tr.geom_traits().construct_vector_3_object();
-    typename Gt::Compute_volume_3 volume = tr.geom_traits().compute_volume_3_object();
+    typename GT::Construct_centroid_3 centroid = tr.geom_traits().construct_centroid_3_object();
+    typename GT::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
+    typename GT::Construct_tetrahedron_3 tetrahedron = tr.geom_traits().construct_tetrahedron_3_object();
+    typename GT::Construct_translated_point_3 translate = tr.geom_traits().construct_translated_point_3_object();
+    typename GT::Construct_vector_3 vector = tr.geom_traits().construct_vector_3_object();
+    typename GT::Compute_volume_3 volume = tr.geom_traits().compute_volume_3_object();
 
     Cell_circulator current_cell = tr.incident_cells(edge);
     Cell_circulator done = current_cell;
