@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/SMDS_3/include/CGAL/Mesh_complex_3_in_triangulation_3.h $
-// $Id: Mesh_complex_3_in_triangulation_3.h 369cfb6a373 2024-03-21T17:08:53+01:00 Jane Tournois
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/SMDS_3/include/CGAL/Mesh_complex_3_in_triangulation_3.h $
+// $Id: include/CGAL/Mesh_complex_3_in_triangulation_3.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -37,7 +37,6 @@
 #include <boost/bimap/multiset_of.hpp>
 #include <CGAL/boost/iterator/transform_iterator.hpp>
 #include <boost/iterator/iterator_adaptor.hpp>
-#include <boost/mpl/if.hpp>
 #include <boost/unordered_map.hpp>
 #include <boost/static_assert.hpp>
 #include <boost/type_traits/is_same.hpp>
@@ -151,7 +150,7 @@ namespace CGAL {
   vertex and cell base class are models of the concepts
   `SimplicialMeshVertexBase_3` and `SimplicialMeshCellBase_3`, respectively.
 
-  \tparam  CornerIndex Type of indices for corners (i.e.\f$ 0\f$--dimensional features)
+  \tparam CornerIndex Type of indices for corners (i.e.\f$ 0\f$--dimensional features)
   of the discretized geometric domain.
   It must be a model of `CopyConstructible`, `Assignable`, `DefaultConstructible` and
   `LessThanComparable`.
@@ -170,7 +169,7 @@ namespace CGAL {
   if the domain used for mesh generation does not include 0 and 1-dimensionnal features (i.e
   is only a model of the concept `MeshDomain_3`).
 
-  \cgalModels `MeshComplexWithFeatures_3InTriangulation_3`
+  \cgalModels{MeshComplexWithFeatures_3InTriangulation_3}
 
   \sa \link make_mesh_3() `CGAL::make_mesh_3()`\endlink
   \sa \link refine_mesh_3() `CGAL::refine_mesh_3()`\endlink
@@ -445,8 +444,8 @@ public:
    */
   void remove_from_complex(const Vertex_handle& v)
   {
-    corners_.erase(v);
     v->set_dimension(-1);
+    corners_.erase(v);
   }
 
   /** sets the index of vertex \p vertex to \p index
@@ -984,7 +983,7 @@ private:
     pointer operator->() const { return *(this->base()); }
     reference operator*() const { return **(this->base()); }
 
-    operator Vertex_handle() { return Vertex_handle(*(this->base())); }
+    operator const Vertex_handle&() const { return *(this->base()); }
   };
 
 public:
@@ -1049,13 +1048,13 @@ public:
     Self operator++(int) { Self tmp(*this); ++(*this); return tmp; }
     Self operator--(int) { Self tmp(*this); --(*this); return tmp; }
 
-    operator Cell_handle() const { return Cell_handle(this->base()); }
+    operator const Cell_handle&() const { return this->base(); }
   }; // end class Cells_in_complex_iterator
 
-  typedef Iterator_range<Prevent_deref<Vertices_in_complex_iterator> > Vertices_in_complex;
-  typedef Iterator_range<Edges_in_complex_iterator>                    Edges_in_complex;
-  typedef Iterator_range<Facets_in_complex_iterator>                   Facets_in_complex;
-  typedef Iterator_range<Prevent_deref<Cells_in_complex_iterator> >    Cells_in_complex;
+  typedef Iterator_range<Prevent_deref<Vertices_in_complex_iterator, const Vertex_handle&>> Vertices_in_complex;
+  typedef Iterator_range<Edges_in_complex_iterator> Edges_in_complex;
+  typedef Iterator_range<Facets_in_complex_iterator> Facets_in_complex;
+  typedef Iterator_range<Prevent_deref<Cells_in_complex_iterator, const Cell_handle&>> Cells_in_complex;
 
 #endif
 
@@ -1163,8 +1162,7 @@ public:
   */
   Vertices_in_complex vertices_in_complex() const
   {
-    return make_prevent_deref_range(vertices_in_complex_begin(),
-                                    vertices_in_complex_end());
+      return { vertices_in_complex_begin(), vertices_in_complex_end() };
   }
   /*!
     returns a range of iterators over the edges of the 1D complex,
@@ -1194,8 +1192,7 @@ public:
   */
   Cells_in_complex cells_in_complex() const
   {
-    return make_prevent_deref_range(cells_in_complex_begin(),
-                                    cells_in_complex_end());
+    return { cells_in_complex_begin(), cells_in_complex_end() };
   }
 ///  @}
 
