@@ -7,9 +7,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Bounding_volumes/include/CGAL/Min_sphere_annulus_d_traits_3.h $
-// $Id: Min_sphere_annulus_d_traits_3.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Bounding_volumes/include/CGAL/Min_sphere_annulus_d_traits_3.h $
+// $Id: include/CGAL/Min_sphere_annulus_d_traits_3.h 50219fc33bc $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Sven Schoenherr <sven@inf.ethz.ch>
@@ -17,6 +17,9 @@
 #ifndef CGAL_MIN_SPHERE_ANNULUS_D_TRAITS_3_H
 #define CGAL_MIN_SPHERE_ANNULUS_D_TRAITS_3_H
 
+#include <CGAL/license/Bounding_volumes.h>
+
+
 // includes
 #  include <CGAL/Optimisation/Access_dimension_3.h>
 #  include <CGAL/Optimisation/Access_coordinates_begin_3.h>
