@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Nef_3/include/CGAL/Nef_3/Infimaximal_box.h $
-// $Id: Infimaximal_box.h f20af1a946c 2025-01-30T18:17:12+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Nef_3/include/CGAL/Nef_3/Infimaximal_box.h $
+// $Id: include/CGAL/Nef_3/Infimaximal_box.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -402,9 +402,9 @@ class Infimaximal_box<Tag_true, Kernel> {
     typename SNC_structure::Vertex_const_iterator v;
     CGAL_forall_vertices(v, snc) {
       Point_3 p(v->point());
-      if(abs(p.hx()[0]) > eval) eval = abs(p.hx()[0]);
-      if(abs(p.hy()[0]) > eval) eval = abs(p.hy()[0]);
-      if(abs(p.hz()[0]) > eval) eval = abs(p.hz()[0]);
+      if(p.hx()[0] > eval) eval = p.hx()[0];
+      if(p.hy()[0] > eval) eval = p.hy()[0];
+      if(p.hz()[0] > eval) eval = p.hz()[0];
     }
     eval *= 4;
     if(eval == 0) return 1;
