@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/NewKernel_d/include/CGAL/NewKernel_d/Cartesian_LA_base.h $
-// $Id: Cartesian_LA_base.h bdc0ce34cd3 2021-01-27T16:33:59+01:00 Marc Glisse
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/NewKernel_d/include/CGAL/NewKernel_d/Cartesian_LA_base.h $
+// $Id: include/CGAL/NewKernel_d/Cartesian_LA_base.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Marc Glisse
@@ -13,7 +13,7 @@
 #define CGAL_KERNEL_D_CARTESIAN_LA_BASE_H
 #include <CGAL/basic.h>
 #include <CGAL/Origin.h>
-#include <boost/type_traits/integral_constant.hpp>
+#include <type_traits>
 #include <CGAL/representation_tags.h>
 #include <CGAL/NewKernel_d/functor_tags.h>
 #include <CGAL/Uncertain.h>
@@ -89,7 +89,7 @@ struct Cartesian_LA_base_d : public Dimension_base<Dim_>
       ::add<Vector_cartesian_const_iterator_tag>::type
       Iterator_list;
 
-    template<class, class=void, class=boost::integral_constant<int,0> > struct Functor {
+    template<class, class=void, class=std::integral_constant<int,0> > struct Functor {
             typedef Null_functor type;
     };
     template<class D> struct Functor<Construct_ttag<Vector_tag>,D> {
@@ -105,19 +105,19 @@ struct Cartesian_LA_base_d : public Dimension_base<Dim_>
             typedef CartesianDVectorBase::Construct_cartesian_const_iterator<Self> type;
     };
     template<class D> struct Functor<Sum_of_vectors_tag,D,
-      boost::integral_constant<int,!LA_vector::template Property<Has_vector_plus_minus_tag>::value> > {
+      std::integral_constant<int,!LA_vector::template Property<Has_vector_plus_minus_tag>::value> > {
             typedef CartesianDVectorBase::Sum_of_vectors<Self> type;
     };
     template<class D> struct Functor<Difference_of_vectors_tag,D,
-      boost::integral_constant<int,!LA_vector::template Property<Has_vector_plus_minus_tag>::value> > {
+      std::integral_constant<int,!LA_vector::template Property<Has_vector_plus_minus_tag>::value> > {
             typedef CartesianDVectorBase::Difference_of_vectors<Self> type;
     };
     template<class D> struct Functor<Opposite_vector_tag,D,
-      boost::integral_constant<int,!LA_vector::template Property<Has_vector_plus_minus_tag>::value> > {
+      std::integral_constant<int,!LA_vector::template Property<Has_vector_plus_minus_tag>::value> > {
             typedef CartesianDVectorBase::Opposite_vector<Self> type;
     };
     template<class D> struct Functor<Midpoint_tag,D,
-      boost::integral_constant<int,
+      std::integral_constant<int,
            !LA_vector::template Property<Has_vector_plus_minus_tag>::value
         || !LA_vector::template Property<Has_vector_scalar_ops_tag>::value> > {
             typedef CartesianDVectorBase::Midpoint<Self> type;
@@ -135,24 +135,24 @@ struct Cartesian_LA_base_d : public Dimension_base<Dim_>
             typedef CartesianDVectorBase::PV_dimension<Self> type;
     };
     template<class D> struct Functor<Orientation_of_vectors_tag,D,
-      boost::integral_constant<int,!LA_vector::template Property<Has_determinant_of_iterator_to_vectors_tag>::value> > {
+      std::integral_constant<int,!LA_vector::template Property<Has_determinant_of_iterator_to_vectors_tag>::value> > {
             typedef CartesianDVectorBase::Orientation_of_vectors<Self> type;
     };
     template<class D> struct Functor<Orientation_of_points_tag,D,
-      boost::integral_constant<int,!LA_vector::template Property<Has_determinant_of_iterator_to_points_tag>::value> > {
+      std::integral_constant<int,!LA_vector::template Property<Has_determinant_of_iterator_to_points_tag>::value> > {
             typedef CartesianDVectorBase::Orientation_of_points<Self> type;
     };
     template<class D> struct Functor<Scalar_product_tag,D,
-      boost::integral_constant<int,!LA_vector::template Property<Has_dot_product_tag>::value> > {
+      std::integral_constant<int,!LA_vector::template Property<Has_dot_product_tag>::value> > {
             typedef CartesianDVectorBase::Scalar_product<Self> type;
     };
     template<class D> struct Functor<Squared_distance_to_origin_tag,D,
-      boost::integral_constant<int,!LA_vector::template Property<Stores_squared_norm_tag>::value> > {
+      std::integral_constant<int,!LA_vector::template Property<Stores_squared_norm_tag>::value> > {
             typedef CartesianDVectorBase::Squared_distance_to_origin_stored<Self> type;
     };
     // Use integral_constant<int,2> in case of failure, to distinguish from the previous one.
     template<class D> struct Functor<Squared_distance_to_origin_tag,D,
-      boost::integral_constant<int,
+      std::integral_constant<int,
         (LA_vector::template Property<Stores_squared_norm_tag>::value
          || !LA_vector::template Property<Has_dot_product_tag>::value)*2> > {
             typedef CartesianDVectorBase::Squared_distance_to_origin_via_dotprod<Self> type;
