@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/NewKernel_d/include/CGAL/NewKernel_d/Cartesian_filter_K.h $
-// $Id: Cartesian_filter_K.h 634fe394bad 2020-12-30T19:56:58+01:00 Marc Glisse
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/NewKernel_d/include/CGAL/NewKernel_d/Cartesian_filter_K.h $
+// $Id: include/CGAL/NewKernel_d/Cartesian_filter_K.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Marc Glisse
@@ -15,7 +15,6 @@
 #include <CGAL/basic.h>
 #include <CGAL/NewKernel_d/KernelD_converter.h>
 #include <CGAL/NewKernel_d/Filtered_predicate2.h>
-#include <boost/mpl/if.hpp>
 #include <boost/mpl/and.hpp>
 
 namespace CGAL {
@@ -65,10 +64,10 @@ struct Cartesian_filter_K : public Base_
     EK_rt exact_kernel()const{return sek.kernel();}
 
     // MSVC is too dumb to perform the empty base optimization.
-    typedef boost::mpl::and_<
-      internal::Do_not_store_kernel<Kernel_base>,
-      internal::Do_not_store_kernel<AK>,
-      internal::Do_not_store_kernel<EK> > Do_not_store_kernel;
+    typedef std::bool_constant<
+      internal::Do_not_store_kernel<Kernel_base>::value &&
+      internal::Do_not_store_kernel<AK>::value &&
+      internal::Do_not_store_kernel<EK>::value > Do_not_store_kernel;
 
     //TODO: C2A/C2E could be able to convert *this into this->kernel() or this->kernel2().
     typedef KernelD_converter<Kernel_base,AK> C2A;
