@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Polygon/include/CGAL/Polygon_2.h $
-// $Id: Polygon_2.h 94080248e7d 2023-02-10T15:40:39+01:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Polygon/include/CGAL/Polygon_2.h $
+// $Id: include/CGAL/Polygon_2.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -34,6 +34,7 @@
 #include <CGAL/enum.h>
 
 #include <CGAL/Aff_transformation_2.h>
+#include <CGAL/Container_helper.h>
 
 #include <CGAL/Polygon_2_algorithms.h>
 #include <CGAL/Polygon_2/Polygon_2_vertex_circulator.h>
@@ -160,11 +161,8 @@ class Polygon_2 {
     /// Creates an empty polygon.
     Polygon_2(const Traits & p_traits) : traits(p_traits) {}
 
-    /// Copy constructor.
-    Polygon_2(const Polygon_2<Traits_P,Container_P>& polygon) = default;
-
-    /// Move constructor
-    Polygon_2(Polygon_2<Traits_P,Container_P>&& polygon) = default;
+    // Move constructor
+    // Polygon_2(Polygon_2<Traits_P,Container_P>&& polygon) = default;
 
     /// Creates a polygon with vertices from the sequence
     /// defined by the range \c [first,last).
@@ -175,11 +173,6 @@ class Polygon_2 {
       : d_container(first,last), traits(p_traits)
     {}
 
-#ifndef DOXYGEN_RUNNING
-  Polygon_2& operator=(const Polygon_2&) = default;
-  Polygon_2& operator=(Polygon_2&& p) = default;
-#endif
-
     /// @}
 
     /// \name Modifiers
@@ -543,6 +536,12 @@ class Polygon_2 {
      container().resize(s);
     }
 
+    /// Calls `container().reserve(s)` if this is available for `Container`.
+    void reserve(std::size_t s)
+    {
+      internal::reserve(container(),s);
+    }
+
     /// @}
 
     bool identical(const Polygon_2<Traits_P,Container_P> &q) const
