@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Smoothing/mesh_smoothing_impl.h $
-// $Id: mesh_smoothing_impl.h cf07ee9c91d 2023-05-22T10:54:42+02:00 Charles Gueunet
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Smoothing/mesh_smoothing_impl.h $
+// $Id: include/CGAL/Polygon_mesh_processing/internal/Smoothing/mesh_smoothing_impl.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -24,8 +24,8 @@
 #include <CGAL/Polygon_mesh_processing/shape_predicates.h>
 
 #include <CGAL/AABB_tree.h>
-#include <CGAL/AABB_traits.h>
-#include <CGAL/AABB_triangle_primitive.h>
+#include <CGAL/AABB_traits_3.h>
+#include <CGAL/AABB_triangle_primitive_3.h>
 #include <CGAL/boost/graph/Euler_operations.h>
 #include <CGAL/Dynamic_property_map.h>
 #include <CGAL/Kernel/global_functions_3.h>
@@ -154,11 +154,8 @@ public:
     typedef typename boost::property_map<TriangleMesh,
                                          Edge_property_tag>::type       Marked_edges_map;
 
-    Marked_edges_map marks = get(Edge_property_tag(), mesh_);
+    Marked_edges_map marks = get(Edge_property_tag(), mesh_, false);
 
-    // dynamic pmaps do not have default values...
-    for(edge_descriptor e : edges(mesh_))
-      put(marks, e, false);
     for(edge_descriptor e : edge_range)
       put(marks, e, true);
 #ifdef CGAL_PMP_SMOOTHING_DEBUG
@@ -369,7 +366,7 @@ private:
         s_av(s_av)
     { }
 
-    // next two functions are just for convencience, the only thing ceres cares about is the operator()
+    // next two functions are just for convenience, the only thing ceres cares about is the operator()
     template <typename T>
     FT area(const T x, const T y, const T z) const
     {
