@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Polyline_simplification_2/include/CGAL/Polyline_simplification_2/simplify.h $
-// $Id: simplify.h c8e93570809 2025-02-12T17:50:35Z Andreas Fabri
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Polyline_simplification_2/include/CGAL/Polyline_simplification_2/simplify.h $
+// $Id: include/CGAL/Polyline_simplification_2/simplify.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Andreas Fabri
@@ -154,14 +154,11 @@ public:
       (*it)->set_removable(false);
       ++it;
       for(; it != ite; ++it){
-        if(std::next(it) != ite){
-          Vertex_handle vp = *std::prev(it), vn = *std::next(it);
-          if(vp == vn){
-            (*it)->set_removable(false);
-          }
+        if((std::next(it) != ite) && (std::prev(it)== std::next(it))){
+          (*it)->set_removable(false);
         }
       }
-      it = boost::prior(it);
+      it = std::prev(it);
       (*it)->set_removable(false);
     }
 
@@ -214,7 +211,7 @@ public:
         it != pct.vertices_in_constraint_end(cid);
         ++it){
       if((*it)->is_removable()){
-        boost::optional<FT> dist = cost(pct, it);
+        std::optional<FT> dist = cost(pct, it);
         if(dist){
           (*it)->set_cost(*dist);
           if(! (*mpq).contains(*it)){
@@ -248,9 +245,9 @@ public:
     }
 
     Vertex_handle vh = *it;
-    Vertices_in_constraint_iterator u = boost::prior(it);
+    Vertices_in_constraint_iterator u = std::prev(it);
     Vertex_handle uh = *u;
-    Vertices_in_constraint_iterator w = boost::next(it);
+    Vertices_in_constraint_iterator w = std::next(it);
     Vertex_handle wh = *w;
 
     typename Geom_traits::Orientation_2 orientation_2 = pct.geom_traits().orientation_2_object();
@@ -325,11 +322,11 @@ operator()()
 
   Vertices_in_constraint_iterator vit = vertex_to_iterator[v].front();
   if(is_removable(vit)){
-    Vertices_in_constraint_iterator u = boost::prior(vit), w = boost::next(vit);
+    Vertices_in_constraint_iterator u = std::prev(vit), w = std::next(vit);
     pct.simplify(vit);
 
     if((*u)->is_removable()){
-      boost::optional<FT> dist = cost(pct, u);
+      std::optional<FT> dist = cost(pct, u);
       if(! dist){
         // cost is undefined
         if( mpq->contains(*u) ){
@@ -347,7 +344,7 @@ operator()()
     }
 
     if((*w)->is_removable()){
-      boost::optional<FT> dist = cost(pct, w);
+      std::optional<FT> dist = cost(pct, w);
       if(! dist){
         // cost is undefined
         if( mpq->contains(*w) ){
