@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Polynomial/include/CGAL/Polynomial/Polynomial_type.h $
-// $Id: Polynomial_type.h eed54a0ae5e 2022-11-15T18:45:39+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Polynomial/include/CGAL/Polynomial/Polynomial_type.h $
+// $Id: include/CGAL/Polynomial/Polynomial_type.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -486,9 +486,9 @@ public:
       // and NT would be changed by NTX
       typedef typename Fraction_traits<NTX>::Is_fraction Is_fraction;
       typedef typename Coercion_traits<NT,NTX>::Type Type;
-      typedef typename ::boost::mpl::if_c<
-      ::std::is_same<Type,NT>::value, Is_fraction, CGAL::Tag_false
-        >::type If_decomposable_AND_Type_equals_NT;
+      typedef std::conditional_t<
+      std::is_same_v<Type,NT>, Is_fraction, CGAL::Tag_false
+        > If_decomposable_AND_Type_equals_NT;
 
       return sign_at_(x,If_decomposable_AND_Type_equals_NT());
     }
@@ -545,8 +545,8 @@ public:
      *  Also available as non-member function.
      */
     CGAL::Sign sign() const {
-//        CGAL_static_assertion( (std::is_same< typename Real_embeddable_traits<NT>::Is_real_embeddable,
-//                              CGAL::Tag_true>::value) );
+//        static_assert(std::is_same< typename Real_embeddable_traits<NT>::Is_real_embeddable,
+//                              CGAL::Tag_true>::value);
       return CGAL::sign(lcoeff());
     }
 
