@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/QP_solver/include/CGAL/QP_solver/QP_solver_nonstandardform_impl.h $
-// $Id: QP_solver_nonstandardform_impl.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/QP_solver/include/CGAL/QP_solver/QP_solver_nonstandardform_impl.h $
+// $Id: include/CGAL/QP_solver/QP_solver_nonstandardform_impl.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -13,6 +13,11 @@
 //                 Franz Wessendorp
 //                 Kaspar Fischer
 
+#ifndef CGAL_QP_SOLVER_NONSTANDARDFORM_IMPL_H
+#define CGAL_QP_SOLVER_NONSTANDARDFORM_IMPL_H
+
+#include <CGAL/license/QP_solver.h>
+
 namespace CGAL {
 
 // Looks in x_O_v_i which bound is present for variable i and returns
@@ -219,3 +224,5 @@ init_w()
 } //namespace CGAL
 
 // ===== EOF ==================================================================
+
+#endif // CGAL_QP_SOLVER_NONSTANDARDFORM_IMPL_H
