@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/GraphicsView/include/CGAL/Qt/PolygonWithHolesGraphicsItem.h $
-// $Id: PolygonWithHolesGraphicsItem.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/GraphicsView/include/CGAL/Qt/PolygonWithHolesGraphicsItem.h $
+// $Id: include/CGAL/Qt/PolygonWithHolesGraphicsItem.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -19,7 +19,6 @@
 
 #include <CGAL/Bbox_2.h>
 #include <CGAL/Polygon_with_holes_2.h>
-#include <CGAL/apply_to_range.h>
 #include <CGAL/Qt/PainterOstream.h>
 #include <CGAL/Qt/GraphicsItem.h>
 #include <CGAL/Qt/Converter.h>
