@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Kernel_23/include/CGAL/Segment_2.h $
-// $Id: Segment_2.h 3fa436459d4 2022-06-10T08:41:19+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Kernel_23/include/CGAL/Segment_2.h $
+// $Id: include/CGAL/Segment_2.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -40,7 +40,7 @@ class Segment_2 : public R_::Kernel_base::Segment_2
   typedef typename R_::Kernel_base::Segment_2 RSegment_2;
 
   typedef Segment_2                           Self;
-  CGAL_static_assertion((std::is_same<Self, typename R_::Segment_2>::value));
+  static_assert(std::is_same<Self, typename R_::Segment_2>::value);
 
 public:
 
