@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Shape_detection/include/CGAL/Shape_detection/Efficient_RANSAC/Efficient_RANSAC.h $
-// $Id: Efficient_RANSAC.h 5f0ed6ba7b0 2021-07-29T15:26:22+02:00 Dmitry Anisimov
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Shape_detection/include/CGAL/Shape_detection/Efficient_RANSAC/Efficient_RANSAC.h $
+// $Id: include/CGAL/Shape_detection/Efficient_RANSAC/Efficient_RANSAC.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -37,7 +37,7 @@
 
 // boost --------------
 #include <CGAL/boost/iterator/counting_iterator.hpp>
-#include <boost/shared_ptr.hpp>
+#include <memory>
 #include <boost/make_shared.hpp>
 //---------------------
 
@@ -104,36 +104,36 @@ public:
 
 #ifdef DOXYGEN_RUNNING
   typedef unspecified_type Shape_range;
-  ///< `Iterator_range` with a bidirectional constant iterator type with value type `boost::shared_ptr<Shape>`.
+  ///< `Iterator_range` with a bidirectional constant iterator type with value type `std::shared_ptr<Shape>`.
   typedef unspecified_type Plane_range;
-  ///< `Iterator_range` with a bidirectional constant iterator type with value type `boost::shared_ptr<Plane_shape>`.
+  ///< `Iterator_range` with a bidirectional constant iterator type with value type `std::shared_ptr<Plane_shape>`.
 #else
 
   struct Shape_range : public Iterator_range<
-          typename std::vector<boost::shared_ptr<Shape> >::const_iterator> {
+          typename std::vector<std::shared_ptr<Shape> >::const_iterator> {
     typedef Iterator_range<
-            typename std::vector<boost::shared_ptr<Shape> >::const_iterator> Base;
+            typename std::vector<std::shared_ptr<Shape> >::const_iterator> Base;
 
-    Shape_range(boost::shared_ptr<std::vector<boost::shared_ptr<Shape> > >
+    Shape_range(std::shared_ptr<std::vector<std::shared_ptr<Shape> > >
                 extracted_shapes) : Base(make_range(extracted_shapes->begin(),
                                                     extracted_shapes->end())), m_extracted_shapes(extracted_shapes) {}
 
   private:
-    boost::shared_ptr<std::vector<boost::shared_ptr<Shape> > >
+    std::shared_ptr<std::vector<std::shared_ptr<Shape> > >
             m_extracted_shapes; // keeps a reference to the shape vector
   };
 
   struct Plane_range : public Iterator_range<
-          typename std::vector<boost::shared_ptr<Plane_shape> >::const_iterator> {
+          typename std::vector<std::shared_ptr<Plane_shape> >::const_iterator> {
     typedef Iterator_range<
-            typename std::vector<boost::shared_ptr<Plane_shape> >::const_iterator> Base;
+            typename std::vector<std::shared_ptr<Plane_shape> >::const_iterator> Base;
 
-    Plane_range(boost::shared_ptr<std::vector<boost::shared_ptr<Plane_shape> > >
+    Plane_range(std::shared_ptr<std::vector<std::shared_ptr<Plane_shape> > >
                 extracted_shapes) : Base(make_range(extracted_shapes->begin(),
                                                     extracted_shapes->end())), m_extracted_shapes(extracted_shapes) {}
 
   private:
-    boost::shared_ptr<std::vector<boost::shared_ptr<Plane_shape> > >
+    std::shared_ptr<std::vector<std::shared_ptr<Plane_shape> > >
             m_extracted_shapes; // keeps a reference to the shape vector
   };
 
@@ -253,12 +253,12 @@ public:
   /*!
     Retrieves the point property map.
   */
-  const Point_map &point_map() const { return m_point_pmap; }
+  const Point_map &point_map() const { return *m_point_pmap; }
 
   /*!
     Retrieves the normal property map.
   */
-  const Normal_map &normal() const { return m_normal_pmap; }
+  const Normal_map &normal() const { return *m_normal_pmap; }
 
   Input_iterator input_iterator_first() const {
     return m_input_iterator_first;
@@ -291,7 +291,7 @@ public:
     clear();
 
     m_extracted_shapes =
-            boost::make_shared<std::vector<boost::shared_ptr<Shape> > >();
+            std::make_shared<std::vector<std::shared_ptr<Shape> > >();
 
     m_num_available_points = m_num_total_points = std::distance(
             m_input_iterator_first, m_input_iterator_beyond);
@@ -361,13 +361,13 @@ public:
         m_direct_octrees[s] = new Direct_octree(
                 m_traits, last + 1,
                 last + subsetSize + 1,
-                m_point_pmap,
+                *m_point_pmap,
                 remainingPoints - subsetSize);
       } else
         m_direct_octrees[0] = new Direct_octree(
                 m_traits, m_input_iterator_first,
                 m_input_iterator_first + (subsetSize),
-                m_point_pmap,
+                *m_point_pmap,
                 0);
 
       m_available_octree_sizes[s] = subsetSize;
@@ -378,7 +378,7 @@ public:
 
     m_global_octree = new Indexed_octree(
             m_traits, m_input_iterator_first, m_input_iterator_beyond,
-            m_point_pmap
+            *m_point_pmap
     );
     m_global_octree->refine(m_options.cluster_epsilon);
 
@@ -435,7 +435,7 @@ public:
     std::vector<int>().swap(m_shape_index);
 
     m_extracted_shapes =
-            boost::make_shared<std::vector<boost::shared_ptr<Shape> > >();
+            std::make_shared<std::vector<std::shared_ptr<Shape> > >();
 
     m_num_available_points = m_num_total_points;
 
@@ -488,7 +488,7 @@ public:
 
     // Reset data structures possibly used by former search
     m_extracted_shapes =
-            boost::make_shared<std::vector<boost::shared_ptr<Shape> > >();
+            std::make_shared<std::vector<std::shared_ptr<Shape> > >();
     m_num_available_points = m_num_total_points;
 
     for (std::size_t i = 0; i < m_num_subsets; i++) {
@@ -496,7 +496,7 @@ public:
     }
 
     // Use bounding box diagonal as reference for default values
-    Bbox_3 bbox = m_global_octree->boundingBox();
+    auto bbox = m_global_octree->boundingBox();
     FT bbox_diagonal = (FT) CGAL::sqrt(
             (bbox.xmax() - bbox.xmin()) * (bbox.xmax() - bbox.xmin())
             + (bbox.ymax() - bbox.ymin()) * (bbox.ymax() - bbox.ymin())
@@ -574,14 +574,14 @@ public:
                     static_cast<unsigned int>(m_num_available_points));
                 while (m_shape_index[first_sample] != -1);
 
-                done = drawSamplesFromCellContainingPoint
-                  (m_global_octree,
-                   get(m_point_pmap,
-                       *(m_input_iterator_first + first_sample)),
-                   select_random_octree_level(),
-                   indices,
-                   m_shape_index,
-                   m_required_samples);
+                done = drawSamplesFromCellContainingPoint(
+                  m_global_octree,
+                  get(*m_point_pmap, *(m_input_iterator_first + first_sample)),
+                  select_random_octree_level(),
+                  indices,
+                  m_shape_index,
+                  m_required_samples
+                );
 
                 if (callback && !callback(num_invalid / double(m_num_total_points))) {
                   clear(num_invalid, candidates);
@@ -605,8 +605,8 @@ public:
                 p->compute(indices,
                            m_input_iterator_first,
                            m_traits,
-                           m_point_pmap,
-                           m_normal_pmap,
+                           *m_point_pmap,
+                           *m_normal_pmap,
                            m_options.epsilon,
                            m_options.normal_threshold);
 
@@ -755,7 +755,7 @@ public:
 
         //1. add best candidate to final result.
         m_extracted_shapes->push_back(
-                boost::shared_ptr<Shape>(best_candidate));
+                std::shared_ptr<Shape>(best_candidate));
 
         if (callback && !callback(num_invalid / double(m_num_total_points))) {
           clear(num_invalid, candidates);
@@ -874,7 +874,7 @@ public:
   /// @{
   /*!
     Returns an `Iterator_range` with a bidirectional iterator with value type
-    `boost::shared_ptr<Shape>` over the detected shapes in the order of detection.
+    `std::shared_ptr<Shape>` over the detected shapes in the order of detection.
     Depending on the chosen probability
     for the detection, the shapes are ordered with decreasing size.
   */
@@ -884,21 +884,21 @@ public:
 
   /*!
     Returns an `Iterator_range` with a bidirectional iterator with
-    value type `boost::shared_ptr<Plane_shape>` over only the
+    value type `std::shared_ptr<Plane_shape>` over only the
     detected planes in the order of detection.  Depending on the
     chosen probability for the detection, the planes are ordered
     with decreasing size.
   */
   Plane_range planes() const {
-    boost::shared_ptr<std::vector<boost::shared_ptr<Plane_shape> > > planes
-            = boost::make_shared<std::vector<boost::shared_ptr<Plane_shape> > >();
+    std::shared_ptr<std::vector<std::shared_ptr<Plane_shape> > > planes
+            = std::make_shared<std::vector<std::shared_ptr<Plane_shape> > >();
 
     for (std::size_t i = 0; i < m_extracted_shapes->size(); ++i) {
-      boost::shared_ptr<Plane_shape> pshape
-              = boost::dynamic_pointer_cast<Plane_shape>((*m_extracted_shapes)[i]);
+      std::shared_ptr<Plane_shape> pshape
+              = std::dynamic_pointer_cast<Plane_shape>((*m_extracted_shapes)[i]);
 
       // Ignore all shapes other than plane
-      if (pshape != boost::shared_ptr<Plane_shape>())
+      if (pshape != std::shared_ptr<Plane_shape>())
         planes->push_back(pshape);
     }
     return Plane_range(planes);
@@ -1086,7 +1086,7 @@ private:
       Cell cell = stack.top();
       stack.pop();
 
-      FT width = octree->width() / (1 << (cell.depth()));
+      FT width = octree->width() / (1 << (octree->depth(cell)));
 
       FT diag = CGAL::sqrt(FT(3) * width * width) + epsilon;
 
@@ -1097,10 +1097,10 @@ private:
 
       // differ between full or partial overlap?
       // if full overlap further traversal of this branch is not necessary
-      if (cell.is_leaf()) {
+      if (octree->is_leaf(cell)) {
         std::vector<std::size_t> indices;
-        indices.reserve(cell.size());
-        for (std::size_t i = 0; i < cell.size(); i++) {
+        indices.reserve(octree->points(cell).size());
+        for (std::size_t i = 0; i < octree->points(cell).size(); i++) {
           if (shapeIndex[octree->index(cell, i)] == -1) {
             indices.push_back(octree->index(cell, i));
           }
@@ -1111,10 +1111,10 @@ private:
                                  indices);
       } else {
 
-        if (!cell.is_leaf()) {
+        if (!octree->is_leaf(cell)) {
           for (std::size_t i = 0; i < 8; i++) {
-            if (!cell[i].empty())
-              stack.push(cell[i]);
+            if (octree->points(octree->child(cell, i)).size() != 0)
+              stack.push(octree->child(cell, i));
           }
         }
       }
@@ -1129,30 +1129,11 @@ private:
   const typename Octree::Node node_containing_point(const Octree *octree, const Point &p, std::size_t level) {
 
     // Find the node containing the point
-    typename Octree::Node cur = octree->root();
-    while (!cur.is_null() && cur.depth() < level) {
+    typename Octree::Node n = octree->locate(p);
+    while (octree->depth(n) > level)
+      n = octree->parent(n);
 
-      // If cur is a leaf node, its child is null
-      if (cur.is_leaf())
-        return typename Octree::Node();
-
-      // If that child is empty, return null
-      if (cur.empty())
-        return typename Octree::Node();
-
-      // Determine the coordinate of the child
-      Point center = octree->barycenter(cur);
-      std::bitset<3> coordinate;
-      coordinate[0] = center.x() <= p.x();
-      coordinate[1] = center.y() <= p.y();
-      coordinate[2] = center.z() <= p.z();
-
-      // Otherwise, return the correct child of cur
-      cur = cur[coordinate.to_ulong()];
-
-    }
-
-    return cur;
+    return n;
   }
 
   template<class Octree>
@@ -1167,13 +1148,9 @@ private:
 
     const Cell cur = node_containing_point(octree, p, level);
 
-    // Stop if the node we need doesn't exist
-    if (cur.is_null())
-      return false;
-
     // Count point indices that map to -1 in the shape index
     std::size_t enough = 0;
-    for (auto j : cur) {
+    for (const auto j : octree->points(cur)) {
       if (shapeIndex[j] == -1)
         enough++;
       if (enough >= requiredSamples)
@@ -1186,7 +1163,7 @@ private:
 
     do {
       std::size_t p = CGAL::get_default_random().
-              uniform_int<std::size_t>(0, cur.size() - 1);
+              uniform_int<std::size_t>(0, octree->points(cur).size() - 1);
       std::size_t j = octree->index(cur, p);
 
       if (shapeIndex[j] == -1)
@@ -1218,15 +1195,15 @@ private:
   //give the index of the subset of point i
   std::vector<int> m_index_subsets;
 
-  boost::shared_ptr<std::vector<boost::shared_ptr<Shape> > > m_extracted_shapes;
+  std::shared_ptr<std::vector<std::shared_ptr<Shape> > > m_extracted_shapes;
 
   std::vector<Shape *(*)()> m_shape_factories;
 
   // iterators of input data
   bool m_valid_iterators;
   Input_iterator m_input_iterator_first, m_input_iterator_beyond;
-  Point_map m_point_pmap;
-  Normal_map m_normal_pmap;
+  std::optional<Point_map> m_point_pmap;
+  std::optional<Normal_map> m_normal_pmap;
 };
 
 
