@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Surface_mesh_deformation/include/CGAL/Surface_mesh_deformation.h $
-// $Id: Surface_mesh_deformation.h f2ad1b25bcd 2024-11-12T09:34:36+01:00 Sven Oesau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Surface_mesh_deformation/include/CGAL/Surface_mesh_deformation.h $
+// $Id: include/CGAL/Surface_mesh_deformation.h 50219fc33bc $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Yin Xu, Andreas Fabri and Ilker O. Yaz
@@ -90,10 +90,10 @@ struct Types_selectors<TriangleMesh, VertexPointMap, CGAL::SPOKES_AND_RIMS>
 
   struct ARAP_visitor
   {
-    void init(const TriangleMesh&, VertexPointMap){}
+    void init(TriangleMesh, VertexPointMap){}
 
     void rotation_matrix_pre(typename boost::graph_traits<TriangleMesh>::vertex_descriptor,
-                             const TriangleMesh&){}
+                             TriangleMesh&){}
 
     template <class Square_matrix_3>
     void update_covariance_matrix(Square_matrix_3&,
@@ -125,7 +125,7 @@ struct Types_selectors<TriangleMesh, VertexPointMap, CGAL::SRE_ARAP>
   public:
     ARAP_visitor(): m_alpha(0.02) {}
 
-    void init(const TriangleMesh &triangle_mesh, const VertexPointMap& vpmap)
+    void init(TriangleMesh triangle_mesh, const VertexPointMap& vpmap)
     {
       // calculate area
       m_area = 0;
@@ -143,7 +143,7 @@ struct Types_selectors<TriangleMesh, VertexPointMap, CGAL::SRE_ARAP>
 
     void rotation_matrix_pre(
       typename boost::graph_traits<TriangleMesh>::vertex_descriptor vi,
-      const TriangleMesh& hg)
+      TriangleMesh& hg)
     {
       typename boost::graph_traits<TriangleMesh>::in_edge_iterator e, e_end;
       std::tie(e,e_end) = in_edges(vi, hg);
